# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: motion-master.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='motion-master.proto',
  package='motionmaster',
  syntax='proto3',
  serialized_options=b'\n\033com.synapticon.motionmasterH\001',
  serialized_pb=b'\n\x13motion-master.proto\x12\x0cmotionmaster\"\xe6\x8d\x02\n\x13MotionMasterMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12<\n\x07request\x18\x65 \x01(\x0b\x32).motionmaster.MotionMasterMessage.RequestH\x00\x12:\n\x06status\x18\x66 \x01(\x0b\x32(.motionmaster.MotionMasterMessage.StatusH\x00\x1a\xc1\x65\n\x07Request\x12\r\n\x05topic\x18\x01 \x01(\t\x12K\n\x0bping_system\x18\x65 \x01(\x0b\x32\x34.motionmaster.MotionMasterMessage.Request.PingSystemH\x00\x12X\n\x12get_system_version\x18\x66 \x01(\x0b\x32:.motionmaster.MotionMasterMessage.Request.GetSystemVersionH\x00\x12R\n\x0fget_device_info\x18g \x01(\x0b\x32\x37.motionmaster.MotionMasterMessage.Request.GetDeviceInfoH\x00\x12\x65\n\x19get_device_parameter_info\x18h \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Request.GetDeviceParameterInfoH\x00\x12i\n\x1bget_device_parameter_values\x18i \x01(\x0b\x32\x42.motionmaster.MotionMasterMessage.Request.GetDeviceParameterValuesH\x00\x12t\n!get_multi_device_parameter_values\x18j \x01(\x0b\x32G.motionmaster.MotionMasterMessage.Request.GetMultiDeviceParameterValuesH\x00\x12i\n\x1bset_device_parameter_values\x18k \x01(\x0b\x32\x42.motionmaster.MotionMasterMessage.Request.SetDeviceParameterValuesH\x00\x12t\n!set_multi_device_parameter_values\x18l \x01(\x0b\x32G.motionmaster.MotionMasterMessage.Request.SetMultiDeviceParameterValuesH\x00\x12[\n\x14get_device_file_list\x18m \x01(\x0b\x32;.motionmaster.MotionMasterMessage.Request.GetDeviceFileListH\x00\x12R\n\x0fget_device_file\x18n \x01(\x0b\x32\x37.motionmaster.MotionMasterMessage.Request.GetDeviceFileH\x00\x12R\n\x0fset_device_file\x18o \x01(\x0b\x32\x37.motionmaster.MotionMasterMessage.Request.SetDeviceFileH\x00\x12X\n\x12\x64\x65lete_device_file\x18p \x01(\x0b\x32:.motionmaster.MotionMasterMessage.Request.DeleteDeviceFileH\x00\x12X\n\x12reset_device_fault\x18q \x01(\x0b\x32:.motionmaster.MotionMasterMessage.Request.ResetDeviceFaultH\x00\x12K\n\x0bstop_device\x18r \x01(\x0b\x32\x34.motionmaster.MotionMasterMessage.Request.StopDeviceH\x00\x12w\n\"start_device_firmware_installation\x18s \x01(\x0b\x32I.motionmaster.MotionMasterMessage.Request.StartDeviceFirmwareInstallationH\x00\x12P\n\x0eget_device_log\x18t \x01(\x0b\x32\x36.motionmaster.MotionMasterMessage.Request.GetDeviceLogH\x00\x12o\n\x1estart_cogging_torque_recording\x18u \x01(\x0b\x32\x45.motionmaster.MotionMasterMessage.Request.StartCoggingTorqueRecordingH\x00\x12\x61\n\x17get_cogging_torque_data\x18v \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Request.GetCoggingTorqueDataH\x00\x12`\n\x16start_offset_detection\x18w \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Request.StartOffsetDetectionH\x00\x12l\n\x1astart_plant_identification\x18x \x01(\x0b\x32\x42.motionmaster.MotionMasterMessage.Request.StartPlantIdentificationB\x02\x18\x01H\x00\x12\x65\n\x19\x63ompute_auto_tuning_gains\x18y \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGainsH\x00\x12s\n set_motion_controller_parameters\x18z \x01(\x0b\x32G.motionmaster.MotionMasterMessage.Request.SetMotionControllerParametersH\x00\x12\x64\n\x18\x65nable_motion_controller\x18{ \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Request.EnableMotionControllerH\x00\x12\x66\n\x19\x64isable_motion_controller\x18| \x01(\x0b\x32\x41.motionmaster.MotionMasterMessage.Request.DisableMotionControllerH\x00\x12q\n\x1fset_signal_generator_parameters\x18} \x01(\x0b\x32\x46.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParametersH\x00\x12`\n\x16start_signal_generator\x18~ \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Request.StartSignalGeneratorH\x00\x12^\n\x15stop_signal_generator\x18\x7f \x01(\x0b\x32=.motionmaster.MotionMasterMessage.Request.StopSignalGeneratorH\x00\x12\x83\x01\n(start_monitoring_device_parameter_values\x18\x80\x01 \x01(\x0b\x32N.motionmaster.MotionMasterMessage.Request.StartMonitoringDeviceParameterValuesH\x00\x12\x81\x01\n\'stop_monitoring_device_parameter_values\x18\x81\x01 \x01(\x0b\x32M.motionmaster.MotionMasterMessage.Request.StopMonitoringDeviceParameterValuesH\x00\x12h\n\x1aget_ethercat_network_state\x18\x82\x01 \x01(\x0b\x32\x41.motionmaster.MotionMasterMessage.Request.GetEthercatNetworkStateH\x00\x12h\n\x1aset_ethercat_network_state\x18\x83\x01 \x01(\x0b\x32\x41.motionmaster.MotionMasterMessage.Request.SetEthercatNetworkStateH\x00\x12t\n\x1estart_narrow_angle_calibration\x18\x84\x01 \x01(\x0b\x32\x45.motionmaster.MotionMasterMessage.Request.StartNarrowAngleCalibrationB\x02\x18\x01H\x00\x12\x66\n\x19set_system_client_timeout\x18\x85\x01 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Request.SetSystemClientTimeoutH\x00\x12k\n\x1bstart_system_identification\x18\x86\x01 \x01(\x0b\x32\x43.motionmaster.MotionMasterMessage.Request.StartSystemIdentificationH\x00\x12y\n#get_circulo_encoder_magnet_distance\x18\x87\x01 \x01(\x0b\x32I.motionmaster.MotionMasterMessage.Request.GetCirculoEncoderMagnetDistanceH\x00\x12\xa1\x01\n8start_circulo_encoder_narrow_angle_calibration_procedure\x18\x88\x01 \x01(\x0b\x32\\.motionmaster.MotionMasterMessage.Request.StartCirculoEncoderNarrowAngleCalibrationProcedureH\x00\x12\x62\n\x17get_device_cia402_state\x18\x89\x01 \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Request.GetDeviceCiA402StateH\x00\x12\x62\n\x17set_device_cia402_state\x18\x8a\x01 \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Request.SetDeviceCiA402StateH\x00\x12Q\n\x0eget_system_log\x18\x8b\x01 \x01(\x0b\x32\x36.motionmaster.MotionMasterMessage.Request.GetSystemLogH\x00\x12\x64\n\x18start_device_sii_restore\x18\x8c\x01 \x01(\x0b\x32?.motionmaster.MotionMasterMessage.Request.StartDeviceSiiRestoreH\x00\x1a\x0c\n\nPingSystem\x1a\x12\n\x10GetSystemVersion\x1a\x0f\n\rGetDeviceInfo\x1a\x30\n\x16GetDeviceParameterInfo\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a\xf2\x01\n\x18GetDeviceParameterValues\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12`\n\nparameters\x18\x02 \x03(\x0b\x32L.motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.Parameter\x12\x15\n\rsend_progress\x18\x03 \x01(\x08\x1a\x45\n\tParameter\x12\r\n\x05index\x18\x01 \x01(\r\x12\x10\n\x08subindex\x18\x02 \x01(\r\x12\x17\n\x0fload_from_cache\x18\x03 \x01(\x08\x1aw\n\x1dGetMultiDeviceParameterValues\x12V\n\ncollection\x18\x01 \x03(\x0b\x32\x42.motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues\x1a\xd0\x02\n\x18SetDeviceParameterValues\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12k\n\x10parameter_values\x18\x03 \x03(\x0b\x32Q.motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue\x1a\xae\x01\n\x0eParameterValue\x12\r\n\x05index\x18\x01 \x01(\r\x12\x10\n\x08subindex\x18\x02 \x01(\r\x12\x13\n\tint_value\x18\x03 \x01(\x12H\x00\x12\x14\n\nuint_value\x18\x04 \x01(\x04H\x00\x12\x15\n\x0b\x66loat_value\x18\x05 \x01(\x02H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x13\n\traw_value\x18\x07 \x01(\x0cH\x00\x42\x0c\n\ntype_value\x1aw\n\x1dSetMultiDeviceParameterValues\x12V\n\ncollection\x18\x01 \x03(\x0b\x32\x42.motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues\x1a+\n\x11GetDeviceFileList\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a\x35\n\rGetDeviceFile\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x1aY\n\rSetDeviceFile\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x11\n\toverwrite\x18\x04 \x01(\x08\x1a\x38\n\x10\x44\x65leteDeviceFile\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a*\n\x10ResetDeviceFault\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a$\n\nStopDevice\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a[\n\x1fStartDeviceFirmwareInstallation\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12 \n\x18\x66irmware_package_content\x18\x02 \x01(\x0c\x1a&\n\x0cGetDeviceLog\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1aO\n\x1bStartCoggingTorqueRecording\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x18\n\x10skip_auto_tuning\x18\x02 \x01(\x08\x1a.\n\x14GetCoggingTorqueData\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a.\n\x14StartOffsetDetection\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a\xb0\x01\n\x18StartPlantIdentification\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x02\x12\x18\n\x10torque_amplitude\x18\x03 \x01(\r\x12\x17\n\x0fstart_frequency\x18\x04 \x01(\r\x12\x15\n\rend_frequency\x18\x05 \x01(\r\x12\x18\n\x10\x63utoff_frequency\x18\x06 \x01(\r\x1a\x97\x01\n\x19StartSystemIdentification\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x02\x12\x18\n\x10torque_amplitude\x18\x03 \x01(\r\x12\x17\n\x0fstart_frequency\x18\x04 \x01(\x02\x12\x15\n\rend_frequency\x18\x05 \x01(\x02\x1a\xa8\x05\n\x16\x43omputeAutoTuningGains\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12r\n\x13position_parameters\x18\x02 \x01(\x0b\x32S.motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParametersH\x00\x12r\n\x13velocity_parameters\x18\x03 \x01(\x0b\x32S.motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.VelocityParametersH\x00\x1a\xb4\x02\n\x12PositionParameters\x12{\n\x0f\x63ontroller_type\x18\x01 \x01(\x0e\x32\x62.motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.ControllerType\x12\x15\n\rsettling_time\x18\x02 \x01(\x02\x12\x18\n\x10position_damping\x18\x03 \x01(\x02\x12\x12\n\nalpha_mult\x18\x04 \x01(\x05\x12\r\n\x05order\x18\x05 \x01(\r\x12\n\n\x02lb\x18\x06 \x01(\x02\x12\n\n\x02ub\x18\x07 \x01(\x02\"5\n\x0e\x43ontrollerType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04PI_P\x10\x01\x12\x08\n\x04P_PI\x10\x02\x1aO\n\x12VelocityParameters\x12\x1f\n\x17velocity_loop_bandwidth\x18\x01 \x01(\x02\x12\x18\n\x10velocity_damping\x18\x02 \x01(\x02\x42\x06\n\x04type\x1aG\n\x1dSetMotionControllerParameters\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x0e\n\x06target\x18\x02 \x01(\x05\x1a\xf5\x01\n\x16\x45nableMotionController\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12h\n\x0f\x63ontroller_type\x18\x02 \x01(\x0e\x32O.motionmaster.MotionMasterMessage.Request.EnableMotionController.ControllerType\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\x08\"I\n\x0e\x43ontrollerType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08POSITION\x10\x01\x12\x0c\n\x08VELOCITY\x10\x02\x12\n\n\x06TORQUE\x10\x03\x1a\x31\n\x17\x44isableMotionController\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a\xfd\"\n\x1cSetSignalGeneratorParameters\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12}\n\x16position_step_response\x18\x02 \x01(\x0b\x32[.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionStepResponseH\x00\x12\x8e\x01\n\x1fposition_advanced_step_response\x18\x03 \x01(\x0b\x32\x63.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponseH\x00\x12l\n\rposition_ramp\x18\x04 \x01(\x0b\x32S.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRampH\x00\x12z\n\x14position_trapezoidal\x18\x05 \x01(\x0b\x32Z.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidalH\x00\x12~\n\x16position_bidirectional\x18\x06 \x01(\x0b\x32\\.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectionalH\x00\x12u\n\x12position_sine_wave\x18\x07 \x01(\x0b\x32W.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWaveH\x00\x12}\n\x16velocity_step_response\x18\x08 \x01(\x0b\x32[.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityStepResponseH\x00\x12\x8e\x01\n\x1fvelocity_advanced_step_response\x18\t \x01(\x0b\x32\x63.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityAdvancedStepResponseH\x00\x12l\n\rvelocity_ramp\x18\n \x01(\x0b\x32S.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRampH\x00\x12z\n\x14velocity_trapezoidal\x18\x0b \x01(\x0b\x32Z.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidalH\x00\x12~\n\x16velocity_bidirectional\x18\x0c \x01(\x0b\x32\\.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectionalH\x00\x12u\n\x12velocity_sine_wave\x18\r \x01(\x0b\x32W.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocitySineWaveH\x00\x12y\n\x14torque_step_response\x18\x0e \x01(\x0b\x32Y.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueStepResponseH\x00\x12\x8a\x01\n\x1dtorque_advanced_step_response\x18\x0f \x01(\x0b\x32\x61.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueAdvancedStepResponseH\x00\x12h\n\x0btorque_ramp\x18\x10 \x01(\x0b\x32Q.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRampH\x00\x12v\n\x12torque_trapezoidal\x18\x11 \x01(\x0b\x32X.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidalH\x00\x12z\n\x14torque_bidirectional\x18\x12 \x01(\x0b\x32Z.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectionalH\x00\x12q\n\x10torque_sine_wave\x18\x13 \x01(\x0b\x32U.motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueSineWaveH\x00\x1aU\n\x14PositionStepResponse\x12\x0e\n\x06target\x18\x01 \x01(\x03\x12\x14\n\x0csustain_time\x18\x02 \x01(\r\x12\x17\n\x0f\x61\x62solute_target\x18\x03 \x01(\x08\x1am\n\x1cPositionAdvancedStepResponse\x12\x0e\n\x06target\x18\x01 \x01(\x03\x12\x14\n\x0csustain_time\x18\x02 \x01(\r\x12\x0e\n\x06repeat\x18\x03 \x01(\x08\x12\x17\n\x0f\x61\x62solute_target\x18\x04 \x01(\x08\x1a\xbd\x01\n\x0cPositionRamp\x12\x0e\n\x06target\x18\x01 \x01(\x03\x12\x18\n\x10profile_velocity\x18\x02 \x01(\r\x12\x1c\n\x14profile_acceleration\x18\x03 \x01(\r\x12\x1c\n\x14profile_deceleration\x18\x04 \x01(\r\x12\x14\n\x0csustain_time\x18\x05 \x01(\r\x12\x18\n\x10master_generated\x18\x06 \x01(\x08\x12\x17\n\x0f\x61\x62solute_target\x18\x07 \x01(\x08\x1a\xd4\x01\n\x13PositionTrapezoidal\x12\x0e\n\x06target\x18\x01 \x01(\x03\x12\x18\n\x10profile_velocity\x18\x02 \x01(\r\x12\x1c\n\x14profile_acceleration\x18\x03 \x01(\r\x12\x1c\n\x14profile_deceleration\x18\x04 \x01(\r\x12\x14\n\x0csustain_time\x18\x05 \x01(\r\x12\x0e\n\x06repeat\x18\x06 \x01(\x08\x12\x18\n\x10master_generated\x18\x07 \x01(\x08\x12\x17\n\x0f\x61\x62solute_target\x18\x08 \x01(\x08\x1a\xd6\x01\n\x15PositionBidirectional\x12\x0e\n\x06target\x18\x01 \x01(\x03\x12\x18\n\x10profile_velocity\x18\x02 \x01(\r\x12\x1c\n\x14profile_acceleration\x18\x03 \x01(\r\x12\x1c\n\x14profile_deceleration\x18\x04 \x01(\r\x12\x14\n\x0csustain_time\x18\x05 \x01(\r\x12\x0e\n\x06repeat\x18\x06 \x01(\x08\x12\x18\n\x10master_generated\x18\x07 \x01(\x08\x12\x17\n\x0f\x61\x62solute_target\x18\x08 \x01(\x08\x1a\x61\n\x10PositionSineWave\x12\x11\n\tamplitude\x18\x01 \x01(\x03\x12\x11\n\tfrequency\x18\x02 \x01(\x02\x12\x0e\n\x06repeat\x18\x03 \x01(\x08\x12\x17\n\x0f\x61\x62solute_target\x18\x04 \x01(\x08\x1a<\n\x14VelocityStepResponse\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x14\n\x0csustain_time\x18\x02 \x01(\r\x1aT\n\x1cVelocityAdvancedStepResponse\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x14\n\x0csustain_time\x18\x02 \x01(\r\x12\x0e\n\x06repeat\x18\x03 \x01(\x08\x1a\x8a\x01\n\x0cVelocityRamp\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x1c\n\x14profile_acceleration\x18\x02 \x01(\r\x12\x1c\n\x14profile_deceleration\x18\x03 \x01(\r\x12\x14\n\x0csustain_time\x18\x04 \x01(\r\x12\x18\n\x10master_generated\x18\x05 \x01(\x08\x1a\xa1\x01\n\x13VelocityTrapezoidal\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x1c\n\x14profile_acceleration\x18\x02 \x01(\r\x12\x1c\n\x14profile_deceleration\x18\x03 \x01(\r\x12\x14\n\x0csustain_time\x18\x04 \x01(\r\x12\x0e\n\x06repeat\x18\x05 \x01(\x08\x12\x18\n\x10master_generated\x18\x06 \x01(\x08\x1a\xa3\x01\n\x15VelocityBidirectional\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x1c\n\x14profile_acceleration\x18\x02 \x01(\r\x12\x1c\n\x14profile_deceleration\x18\x03 \x01(\r\x12\x14\n\x0csustain_time\x18\x04 \x01(\r\x12\x0e\n\x06repeat\x18\x05 \x01(\x08\x12\x18\n\x10master_generated\x18\x06 \x01(\x08\x1aH\n\x10VelocitySineWave\x12\x11\n\tamplitude\x18\x01 \x01(\x05\x12\x11\n\tfrequency\x18\x02 \x01(\x02\x12\x0e\n\x06repeat\x18\x03 \x01(\x08\x1a:\n\x12TorqueStepResponse\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x14\n\x0csustain_time\x18\x02 \x01(\r\x1aR\n\x1aTorqueAdvancedStepResponse\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x14\n\x0csustain_time\x18\x02 \x01(\r\x12\x0e\n\x06repeat\x18\x03 \x01(\x08\x1a\x62\n\nTorqueRamp\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x14\n\x0ctorque_slope\x18\x02 \x01(\r\x12\x14\n\x0csustain_time\x18\x03 \x01(\r\x12\x18\n\x10master_generated\x18\x04 \x01(\x08\x1ay\n\x11TorqueTrapezoidal\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x14\n\x0ctorque_slope\x18\x02 \x01(\r\x12\x14\n\x0csustain_time\x18\x03 \x01(\r\x12\x0e\n\x06repeat\x18\x04 \x01(\x08\x12\x18\n\x10master_generated\x18\x05 \x01(\x08\x1a{\n\x13TorqueBidirectional\x12\x0e\n\x06target\x18\x01 \x01(\x05\x12\x14\n\x0ctorque_slope\x18\x02 \x01(\r\x12\x14\n\x0csustain_time\x18\x03 \x01(\r\x12\x0e\n\x06repeat\x18\x04 \x01(\x08\x12\x18\n\x10master_generated\x18\x05 \x01(\x08\x1a\x46\n\x0eTorqueSineWave\x12\x11\n\tamplitude\x18\x01 \x01(\x05\x12\x11\n\tfrequency\x18\x02 \x01(\x02\x12\x0e\n\x06repeat\x18\x03 \x01(\x08\x42\x08\n\x06signal\x1a.\n\x14StartSignalGenerator\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a-\n\x13StopSignalGenerator\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a\xb0\x01\n$StartMonitoringDeviceParameterValues\x12g\n\x1bget_device_parameter_values\x18\x01 \x01(\x0b\x32\x42.motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues\x12\x10\n\x08interval\x18\x02 \x01(\r\x12\r\n\x05topic\x18\x03 \x01(\t\x1aJ\n#StopMonitoringDeviceParameterValues\x12#\n\x1bstart_monitoring_request_id\x18\x01 \x01(\t\x1a\x31\n\x17GetEthercatNetworkState\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a\xd6\x01\n\x17SetEthercatNetworkState\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12V\n\x05state\x18\x02 \x01(\x0e\x32G.motionmaster.MotionMasterMessage.Request.SetEthercatNetworkState.State\"K\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04INIT\x10\x01\x12\t\n\x05PREOP\x10\x02\x12\x08\n\x04\x42OOT\x10\x03\x12\n\n\x06SAFEOP\x10\x04\x12\x06\n\x02OP\x10\x05\x1a\x35\n\x1bStartNarrowAngleCalibration\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a,\n\x16SetSystemClientTimeout\x12\x12\n\ntimeout_ms\x18\x01 \x01(\r\x1aO\n\x1fGetCirculoEncoderMagnetDistance\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x14\n\x0c\x65ncoder_port\x18\x02 \x01(\r\x1a\x62\n2StartCirculoEncoderNarrowAngleCalibrationProcedure\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x14\n\x0c\x65ncoder_port\x18\x02 \x01(\r\x1a.\n\x14GetDeviceCiA402State\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x1a\xb8\x02\n\x14SetDeviceCiA402State\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12S\n\x05state\x18\x02 \x01(\x0e\x32\x44.motionmaster.MotionMasterMessage.Request.SetDeviceCiA402State.State\"\xb2\x01\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tNOT_READY\x10\x01\x12\x16\n\x12SWITCH_ON_DISABLED\x10\x02\x12\x13\n\x0fREADY_SWITCH_ON\x10\x03\x12\x0f\n\x0bSWITCHED_ON\x10\x04\x12\x0e\n\nOP_ENABLED\x10\x05\x12\x15\n\x11QUICK_STOP_ACTIVE\x10\x06\x12\x19\n\x15\x46\x41ULT_REACTION_ACTIVE\x10\x07\x12\t\n\x05\x46\x41ULT\x10\x08\x1a\x0e\n\x0cGetSystemLog\x1a\x45\n\x15StartDeviceSiiRestore\x12\x17\n\x0f\x64\x65vice_position\x18\x01 \x01(\r\x12\x13\n\x0bsii_content\x18\x02 \x01(\x0c\x42\x06\n\x04typeJ\x04\x08\x02\x10\x65J\x06\x08\x8d\x01\x10\xe9\x07\x1a\xee\xa6\x01\n\x06Status\x12J\n\x0bsystem_pong\x18\x65 \x01(\x0b\x32\x33.motionmaster.MotionMasterMessage.Status.SystemPongH\x00\x12P\n\x0esystem_version\x18\x66 \x01(\x0b\x32\x36.motionmaster.MotionMasterMessage.Status.SystemVersionH\x00\x12L\n\x0csystem_event\x18g \x01(\x0b\x32\x34.motionmaster.MotionMasterMessage.Status.SystemEventH\x00\x12J\n\x0b\x64\x65vice_info\x18h \x01(\x0b\x32\x33.motionmaster.MotionMasterMessage.Status.DeviceInfoH\x00\x12]\n\x15\x64\x65vice_parameter_info\x18i \x01(\x0b\x32<.motionmaster.MotionMasterMessage.Status.DeviceParameterInfoH\x00\x12\x61\n\x17\x64\x65vice_parameter_values\x18j \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Status.DeviceParameterValuesH\x00\x12l\n\x1dmulti_device_parameter_values\x18k \x01(\x0b\x32\x43.motionmaster.MotionMasterMessage.Status.MultiDeviceParameterValuesH\x00\x12S\n\x10\x64\x65vice_file_list\x18l \x01(\x0b\x32\x37.motionmaster.MotionMasterMessage.Status.DeviceFileListH\x00\x12J\n\x0b\x64\x65vice_file\x18m \x01(\x0b\x32\x33.motionmaster.MotionMasterMessage.Status.DeviceFileH\x00\x12L\n\x0c\x64\x65vice_event\x18n \x01(\x0b\x32\x34.motionmaster.MotionMasterMessage.Status.DeviceEventH\x00\x12k\n\x1c\x64\x65vice_firmware_installation\x18o \x01(\x0b\x32\x43.motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallationH\x00\x12H\n\ndevice_log\x18p \x01(\x0b\x32\x32.motionmaster.MotionMasterMessage.Status.DeviceLogH\x00\x12W\n\x12\x64\x65vice_fault_reset\x18q \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.DeviceFaultResetH\x00\x12\x63\n\x18\x63ogging_torque_recording\x18r \x01(\x0b\x32?.motionmaster.MotionMasterMessage.Status.CoggingTorqueRecordingH\x00\x12Y\n\x13\x63ogging_torque_data\x18s \x01(\x0b\x32:.motionmaster.MotionMasterMessage.Status.CoggingTorqueDataH\x00\x12T\n\x10offset_detection\x18t \x01(\x0b\x32\x38.motionmaster.MotionMasterMessage.Status.OffsetDetectionH\x00\x12`\n\x14plant_identification\x18u \x01(\x0b\x32<.motionmaster.MotionMasterMessage.Status.PlantIdentificationB\x02\x18\x01H\x00\x12J\n\x0b\x61uto_tuning\x18v \x01(\x0b\x32\x33.motionmaster.MotionMasterMessage.Status.AutoTuningH\x00\x12V\n\x11motion_controller\x18w \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.MotionControllerH\x00\x12T\n\x10signal_generator\x18x \x01(\x0b\x32\x38.motionmaster.MotionMasterMessage.Status.SignalGeneratorH\x00\x12i\n\x1bmonitoring_parameter_values\x18y \x01(\x0b\x32\x42.motionmaster.MotionMasterMessage.Status.MonitoringParameterValuesH\x00\x12J\n\x0b\x64\x65vice_stop\x18z \x01(\x0b\x32\x33.motionmaster.MotionMasterMessage.Status.DeviceStopH\x00\x12_\n\x16\x65thercat_network_state\x18{ \x01(\x0b\x32=.motionmaster.MotionMasterMessage.Status.EthercatNetworkStateH\x00\x12g\n\x18narrow_angle_calibration\x18| \x01(\x0b\x32?.motionmaster.MotionMasterMessage.Status.NarrowAngleCalibrationB\x02\x18\x01H\x00\x12^\n\x15system_identification\x18} \x01(\x0b\x32=.motionmaster.MotionMasterMessage.Status.SystemIdentificationH\x00\x12p\n\x1f\x63irculo_encoder_magnet_distance\x18~ \x01(\x0b\x32\x45.motionmaster.MotionMasterMessage.Status.CirculoEncoderMagnetDistanceH\x00\x12\x94\x01\n2circulo_encoder_narrow_angle_calibration_procedure\x18\x7f \x01(\x0b\x32V.motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedureH\x00\x12Z\n\x13\x64\x65vice_cia402_state\x18\x80\x01 \x01(\x0b\x32:.motionmaster.MotionMasterMessage.Status.DeviceCiA402StateH\x00\x12I\n\nsystem_log\x18\x81\x01 \x01(\x0b\x32\x32.motionmaster.MotionMasterMessage.Status.SystemLogH\x00\x12X\n\x12\x64\x65vice_sii_restore\x18\x82\x01 \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.DeviceSiiRestoreH\x00\x1a\x0c\n\nSystemPong\x1a \n\rSystemVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x1a\x8d\n\n\x0bSystemEvent\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12I\n\x04info\x18\x02 \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.SystemEvent.InfoH\x00\x12O\n\x07success\x18\x03 \x01(\x0b\x32<.motionmaster.MotionMasterMessage.Status.SystemEvent.SuccessH\x00\x12O\n\x07warning\x18\x04 \x01(\x0b\x32<.motionmaster.MotionMasterMessage.Status.SystemEvent.WarningH\x00\x12K\n\x05\x65rror\x18\x05 \x01(\x0b\x32:.motionmaster.MotionMasterMessage.Status.SystemEvent.ErrorH\x00\x12K\n\x05state\x18\x06 \x01(\x0e\x32:.motionmaster.MotionMasterMessage.Status.SystemEvent.StateH\x00\x1a\x98\x01\n\x04Info\x12L\n\x04\x63ode\x18\x01 \x01(\x0e\x32>.motionmaster.MotionMasterMessage.Status.SystemEvent.Info.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"1\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x18\n\x14SLAVE_NUMBER_CHANGED\x10\x01\x1a\x84\x01\n\x07Success\x12O\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x41.motionmaster.MotionMasterMessage.Status.SystemEvent.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x17\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x1a\x9d\x01\n\x07Warning\x12O\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x41.motionmaster.MotionMasterMessage.Status.SystemEvent.Warning.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"0\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x17\n\x13\x44ROPPING_CONNECTION\x10\x01\x1a\xf2\x01\n\x05\x45rror\x12M\n\x04\x63ode\x18\x01 \x01(\x0e\x32?.motionmaster.MotionMasterMessage.Status.SystemEvent.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x88\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x18\n\x14UNKNOWN_MESSAGE_TYPE\x10\x01\x12\x18\n\x14\x43\x41NNOT_DETECT_SLAVES\x10\x02\x12\x1a\n\x16INVALID_DEVICE_ADDRESS\x10\x03\x12\x1f\n\x1b\x43ONFIGURATION_RELOAD_FAILED\x10\x04\"\x9d\x01\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x16\n\x12WAITING_FOR_SLAVES\x10\x01\x12\x10\n\x0cSLAVES_FOUND\x10\x02\x12\x10\n\x0cINITIALIZING\x10\x03\x12\x0f\n\x0bINITIALIZED\x10\x04\x12\x12\n\x0e\x44\x45INITIALIZING\x10\x05\x12\x11\n\rDEINITIALIZED\x10\x06\x12\x0f\n\x0bTERMINATING\x10\x07\x42\x08\n\x06status\x1a\xbf\x02\n\nDeviceInfo\x12K\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32:.motionmaster.MotionMasterMessage.Status.DeviceInfo.Device\x1a\xe3\x01\n\x06\x44\x65vice\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12M\n\x04type\x18\x02 \x01(\x0e\x32?.motionmaster.MotionMasterMessage.Status.DeviceInfo.Device.Type\x12\x10\n\x08position\x18\x03 \x01(\r\x12\r\n\x05\x61lias\x18\x04 \x01(\r\"Q\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x1b\n\x17SOMANET_CIA401_ETHERCAT\x10\x01\x12\x1b\n\x17SOMANET_CIA402_ETHERCAT\x10\x02\x1a\xec\x04\n\x13\x44\x65viceParameterInfo\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12Z\n\nparameters\x18\x02 \x03(\x0b\x32\x46.motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter\x1a\xe0\x03\n\tParameter\x12\r\n\x05index\x18\x01 \x01(\r\x12\x10\n\x08subindex\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04unit\x18\x04 \x01(\t\x12\r\n\x05group\x18\x05 \x01(\t\x12\x13\n\x0bread_access\x18\x06 \x01(\x08\x12\x14\n\x0cwrite_access\x18\x07 \x01(\x08\x12\x0b\n\x03min\x18\x08 \x01(\x05\x12\x0b\n\x03max\x18\t \x01(\x05\x12\x64\n\nvalue_type\x18\n \x01(\x0e\x32P.motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.ValueType\"\xdb\x01\n\tValueType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\x0c\n\x08INTEGER8\x10\x02\x12\r\n\tINTEGER16\x10\x03\x12\r\n\tINTEGER32\x10\x04\x12\r\n\tUNSIGNED8\x10\x05\x12\x0e\n\nUNSIGNED16\x10\x06\x12\x0e\n\nUNSIGNED32\x10\x07\x12\n\n\x06REAL32\x10\x08\x12\x12\n\x0eVISIBLE_STRING\x10\t\x12\x10\n\x0cOCTET_STRING\x10\n\x12\x12\n\x0eUNICODE_STRING\x10\x0b\x12\x0f\n\x0bTIME_OF_DAY\x10\x0c\x1a\xbc\x08\n\x15\x44\x65viceParameterValues\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12g\n\x10parameter_values\x18\x02 \x03(\x0b\x32M.motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue\x12Y\n\x08progress\x18\x03 \x01(\x0b\x32G.motionmaster.MotionMasterMessage.Status.DeviceParameterValues.Progress\x1a\x95\x06\n\x0eParameterValue\x12\r\n\x05index\x18\x01 \x01(\r\x12\x10\n\x08subindex\x18\x02 \x01(\r\x12\x13\n\tint_value\x18\x03 \x01(\x12H\x00\x12\x14\n\nuint_value\x18\x04 \x01(\x04H\x00\x12\x15\n\x0b\x66loat_value\x18\x05 \x01(\x02H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x13\n\traw_value\x18\x07 \x01(\x0cH\x00\x12h\n\x07success\x18\x08 \x01(\x0b\x32U.motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.SuccessH\x01\x12\x64\n\x05\x65rror\x18\t \x01(\x0b\x32S.motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.ErrorH\x01\x1a\xb4\x01\n\x07Success\x12h\n\x04\x63ode\x18\x01 \x01(\x0e\x32Z.motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x12\x0b\n\x07\x43HANGED\x10\x02\x1a\xd3\x01\n\x05\x45rror\x12\x66\n\x04\x63ode\x18\x01 \x01(\x0e\x32X.motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"Q\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tNOT_FOUND\x10\x01\x12\x18\n\x14\x43\x41NNOT_REFRESH_VALUE\x10\x02\x12\x0f\n\x0bNOT_CHANGED\x10\x03\x42\x0c\n\ntype_valueB\x08\n\x06status\x1a/\n\x08Progress\x12\x12\n\npercentage\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\x1ap\n\x1aMultiDeviceParameterValues\x12R\n\ncollection\x18\x01 \x03(\x0b\x32>.motionmaster.MotionMasterMessage.Status.DeviceParameterValues\x1a\x8b\x03\n\x0e\x44\x65viceFileList\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12U\n\tfile_list\x18\x02 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Status.DeviceFileList.FileListH\x00\x12N\n\x05\x65rror\x18\x03 \x01(\x0b\x32=.motionmaster.MotionMasterMessage.Status.DeviceFileList.ErrorH\x00\x1a\x19\n\x08\x46ileList\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x1a\x96\x01\n\x05\x45rror\x12P\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x42.motionmaster.MotionMasterMessage.Status.DeviceFileList.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"*\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x11\n\rNOT_SUPPORTED\x10\x01\x42\x06\n\x04\x64\x61ta\x1a\xb5\x04\n\nDeviceFile\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\x07\x63ontent\x18\x03 \x01(\x0cH\x00\x12N\n\x07success\x18\x04 \x01(\x0b\x32;.motionmaster.MotionMasterMessage.Status.DeviceFile.SuccessH\x00\x12J\n\x05\x65rror\x18\x05 \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.DeviceFile.ErrorH\x00\x1a\x99\x01\n\x07Success\x12N\n\x04\x63ode\x18\x01 \x01(\x0e\x32@.motionmaster.MotionMasterMessage.Status.DeviceFile.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"-\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03SET\x10\x01\x12\x0b\n\x07\x44\x45LETED\x10\x02\x1a\xad\x01\n\x05\x45rror\x12L\n\x04\x63ode\x18\x01 \x01(\x0e\x32>.motionmaster.MotionMasterMessage.Status.DeviceFile.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"E\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tNOT_FOUND\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x11\n\rNOT_SUPPORTED\x10\x03\x42\x06\n\x04\x64\x61ta\x1a\x8c\x04\n\x0b\x44\x65viceEvent\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12I\n\x04info\x18\x02 \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.DeviceEvent.InfoH\x00\x12O\n\x07success\x18\x03 \x01(\x0b\x32<.motionmaster.MotionMasterMessage.Status.DeviceEvent.SuccessH\x00\x12O\n\x07warning\x18\x04 \x01(\x0b\x32<.motionmaster.MotionMasterMessage.Status.DeviceEvent.WarningH\x00\x12K\n\x05\x65rror\x18\x05 \x01(\x0b\x32:.motionmaster.MotionMasterMessage.Status.DeviceEvent.ErrorH\x00\x1a%\n\x04Info\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a(\n\x07Success\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a(\n\x07Warning\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\x1a&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\tB\x08\n\x06status\x1a\x87\x07\n\x1a\x44\x65viceFirmwareInstallation\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12^\n\x07success\x18\x02 \x01(\x0b\x32K.motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.SuccessH\x00\x12Z\n\x05\x65rror\x18\x03 \x01(\x0b\x32I.motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.ErrorH\x00\x12`\n\x08progress\x18\x04 \x01(\x0b\x32L.motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.ProgressH\x00\x1a\xaa\x01\n\x07Success\x12^\n\x04\x63ode\x18\x01 \x01(\x0e\x32P.motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\xca\x02\n\x05\x45rror\x12\\\n\x04\x63ode\x18\x01 \x01(\x0e\x32N.motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xd1\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x15\n\x11PACKAGE_CORRUPTED\x10\x01\x12\x11\n\rSII_CORRUPTED\x10\x02\x12\x13\n\x0fIMAGE_NOT_FOUND\x10\x03\x12\x0b\n\x07REFUSED\x10\x04\x12\x11\n\rNOT_SUPPORTED\x10\x05\x12\x14\n\x10SII_WRITE_FAILED\x10\x06\x12\x15\n\x11\x46ILE_WRITE_FAILED\x10\x07\x12\x16\n\x12\x46ILE_DELETE_FAILED\x10\x08\x12\x14\n\x10\x44\x45VICE_NOT_FOUND\x10\t\x1a/\n\x08Progress\x12\x12\n\npercentage\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\tB\x08\n\x06status\x1a\xac\x02\n\tDeviceLog\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x11\n\x07\x63ontent\x18\x02 \x01(\tH\x00\x12I\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x38.motionmaster.MotionMasterMessage.Status.DeviceLog.ErrorH\x00\x1a\xa0\x01\n\x05\x45rror\x12K\n\x04\x63ode\x18\x01 \x01(\x0e\x32=.motionmaster.MotionMasterMessage.Status.DeviceLog.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"9\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tNOT_FOUND\x10\x01\x12\x11\n\rNOT_SUPPORTED\x10\x02\x42\x06\n\x04\x64\x61ta\x1a\x98\x06\n\x10\x44\x65viceFaultReset\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12T\n\x07success\x18\x02 \x01(\x0b\x32\x41.motionmaster.MotionMasterMessage.Status.DeviceFaultReset.SuccessH\x00\x12T\n\x07warning\x18\x03 \x01(\x0b\x32\x41.motionmaster.MotionMasterMessage.Status.DeviceFaultReset.WarningH\x00\x12P\n\x05\x65rror\x18\x04 \x01(\x0b\x32?.motionmaster.MotionMasterMessage.Status.DeviceFaultReset.ErrorH\x00\x1a\x93\x01\n\x07Success\x12T\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x46.motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"!\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x1a\x97\x01\n\x07Warning\x12T\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x46.motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Warning.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"%\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08NO_FAULT\x10\x01\x1a\xb3\x01\n\x05\x45rror\x12R\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x44.motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"E\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\r\n\tTIMED_OUT\x10\x02\x12\x11\n\rNOT_SUPPORTED\x10\x03\x42\x08\n\x06status\x1a\xe1\x06\n\x16\x43oggingTorqueRecording\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12Z\n\x07success\x18\x02 \x01(\x0b\x32G.motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.SuccessH\x00\x12V\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x45.motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.ErrorH\x00\x1a\xa6\x01\n\x07Success\x12Z\n\x04\x63ode\x18\x01 \x01(\x0e\x32L.motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\xc7\x03\n\x05\x45rror\x12X\n\x04\x63ode\x18\x01 \x01(\x0e\x32J.motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xd2\x02\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x16\n\x12\x46\x41ILED_HALL_SENSOR\x10\x01\x12\x16\n\x12INVALID_RESOLUTION\x10\x02\x12\x19\n\x15NO_COMMUTATION_SENSOR\x10\x03\x12$\n NO_COMMUTATION_AND_MOTION_SENSOR\x10\x04\x12!\n\x1dPOSITION_CONTROLLER_NOT_TUNED\x10\x05\x12\x0f\n\x0bINIT_FAILED\x10\x06\x12\n\n\x06\x46\x41ILED\x10\x07\x12\x0b\n\x07\x41\x42ORTED\x10\x08\x12\x0b\n\x07TIMEOUT\x10\t\x12\x11\n\rSAVING_FAILED\x10\n\x12\x12\n\x0eSAVING_ABORTED\x10\x0b\x12\x12\n\x0eSAVING_TIMEOUT\x10\x0c\x12 \n\x1cNO_POSITION_CONTROL_FUNCTION\x10\r\x12\x11\n\rNOT_SUPPORTED\x10\x0e\x42\x08\n\x06status\x1a\xaa\x03\n\x11\x43oggingTorqueData\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12Q\n\x05table\x18\x04 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Status.CoggingTorqueData.TableH\x00\x12Q\n\x05\x65rror\x18\x05 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Status.CoggingTorqueData.ErrorH\x00\x1a\x15\n\x05Table\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\x1a\xb7\x01\n\x05\x45rror\x12S\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x45.motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"H\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tNOT_FOUND\x10\x01\x12\r\n\tCORRUPTED\x10\x02\x12\x11\n\rNOT_SUPPORTED\x10\x03\x42\x06\n\x04\x64\x61ta\x1a\xcc\x04\n\x0fOffsetDetection\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12S\n\x07success\x18\x02 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Status.OffsetDetection.SuccessH\x00\x12O\n\x05\x65rror\x18\x03 \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Status.OffsetDetection.ErrorH\x00\x1a\x9f\x01\n\x07Success\x12S\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x45.motionmaster.MotionMasterMessage.Status.OffsetDetection.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\xce\x01\n\x05\x45rror\x12Q\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x43.motionmaster.MotionMasterMessage.Status.OffsetDetection.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"a\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0bINIT_FAILED\x10\x01\x12\x0b\n\x07TIMEOUT\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\x11\n\rNOT_SUPPORTED\x10\x05\x42\x08\n\x06status\x1a\xf2\x05\n\x13PlantIdentification\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12W\n\x07success\x18\x02 \x01(\x0b\x32\x44.motionmaster.MotionMasterMessage.Status.PlantIdentification.SuccessH\x00\x12S\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x42.motionmaster.MotionMasterMessage.Status.PlantIdentification.ErrorH\x00\x1a\xa3\x01\n\x07Success\x12W\n\x04\x63ode\x18\x01 \x01(\x0e\x32I.motionmaster.MotionMasterMessage.Status.PlantIdentification.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\xe4\x02\n\x05\x45rror\x12U\n\x04\x63ode\x18\x01 \x01(\x0e\x32G.motionmaster.MotionMasterMessage.Status.PlantIdentification.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xf2\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x1e\n\x1aNO_POSITION_CONTROL_SENSOR\x10\x01\x12\x0f\n\x0bINIT_FAILED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\r\n\tTIMED_OUT\x10\x05\x12\x19\n\x15ZERO_TORQUE_AMPLITUDE\x10\x06\x12\x1b\n\x17ZERO_VELOCITY_AMPLITUDE\x10\x07\x12\x19\n\x15WRONG_SENSOR_POLARITY\x10\x08\x12\x1a\n\x16SMALL_MOTION_AMPLITUDE\x10\t\x12\x11\n\rNOT_SUPPORTED\x10\nB\x08\n\x06status\x1a\xf7\x05\n\x14SystemIdentification\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12X\n\x07success\x18\x02 \x01(\x0b\x32\x45.motionmaster.MotionMasterMessage.Status.SystemIdentification.SuccessH\x00\x12T\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x43.motionmaster.MotionMasterMessage.Status.SystemIdentification.ErrorH\x00\x1a\xa4\x01\n\x07Success\x12X\n\x04\x63ode\x18\x01 \x01(\x0e\x32J.motionmaster.MotionMasterMessage.Status.SystemIdentification.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\xe5\x02\n\x05\x45rror\x12V\n\x04\x63ode\x18\x01 \x01(\x0e\x32H.motionmaster.MotionMasterMessage.Status.SystemIdentification.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xf2\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x1e\n\x1aNO_POSITION_CONTROL_SENSOR\x10\x01\x12\x0f\n\x0bINIT_FAILED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\r\n\tTIMED_OUT\x10\x05\x12\x19\n\x15ZERO_TORQUE_AMPLITUDE\x10\x06\x12\x1b\n\x17ZERO_VELOCITY_AMPLITUDE\x10\x07\x12\x19\n\x15WRONG_SENSOR_POLARITY\x10\x08\x12\x1a\n\x16SMALL_MOTION_AMPLITUDE\x10\t\x12\x11\n\rNOT_SUPPORTED\x10\nB\x08\n\x06status\x1a\xe2\x07\n\nAutoTuning\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12N\n\x07success\x18\x02 \x01(\x0b\x32;.motionmaster.MotionMasterMessage.Status.AutoTuning.SuccessH\x00\x12N\n\x07warning\x18\x03 \x01(\x0b\x32;.motionmaster.MotionMasterMessage.Status.AutoTuning.WarningH\x00\x12J\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.AutoTuning.ErrorH\x00\x1a\xd5\x01\n\x07Success\x12N\n\x04\x63ode\x18\x01 \x01(\x0e\x32@.motionmaster.MotionMasterMessage.Status.AutoTuning.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"i\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x14\n\x10POSITION_STARTED\x10\x01\x12\x11\n\rPOSITION_DONE\x10\x02\x12\x14\n\x10VELOCITY_STARTED\x10\x03\x12\x11\n\rVELOCITY_DONE\x10\x04\x1a\xd7\x01\n\x07Warning\x12N\n\x04\x63ode\x18\x01 \x01(\x0e\x32@.motionmaster.MotionMasterMessage.Status.AutoTuning.Warning.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"k\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x1d\n\x19SETTLING_TIME_NOT_REACHED\x10\x01\x12\x15\n\x11VELOCITY_UNSTABLE\x10\x02\x12\x1c\n\x18SMALL_VELOCITY_AMPLITUDE\x10\x03\x1a\x93\x02\n\x05\x45rror\x12L\n\x04\x63ode\x18\x01 \x01(\x0e\x32>.motionmaster.MotionMasterMessage.Status.AutoTuning.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xaa\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x17\n\x13PLANT_MODEL_INVALID\x10\x01\x12\x19\n\x15PLANT_MODEL_NOT_FOUND\x10\x02\x12 \n\x1c\x43\x41NNOT_ACHIEVE_SETTLING_TIME\x10\x03\x12\x13\n\x0fPOSITION_FAILED\x10\x04\x12\x13\n\x0fVELOCITY_FAILED\x10\x05\x12\x11\n\rNOT_SUPPORTED\x10\x06\x42\x08\n\x06status\x1a\x86\x07\n\x10MotionController\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x61\n\x0f\x63ontroller_type\x18\x02 \x01(\x0e\x32H.motionmaster.MotionMasterMessage.Status.MotionController.ControllerType\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\x08\x12T\n\x07success\x18\x05 \x01(\x0b\x32\x41.motionmaster.MotionMasterMessage.Status.MotionController.SuccessH\x00\x12P\n\x05\x65rror\x18\x06 \x01(\x0b\x32?.motionmaster.MotionMasterMessage.Status.MotionController.ErrorH\x00\x1a\x93\x01\n\x07Success\x12T\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x46.motionmaster.MotionMasterMessage.Status.MotionController.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"!\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x1a\xc2\x02\n\x05\x45rror\x12R\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x44.motionmaster.MotionMasterMessage.Status.MotionController.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xd3\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x14\n\x10\x43\x41NNOT_GET_STATE\x10\x01\x12\x16\n\x12\x43\x41NNOT_GET_OP_MODE\x10\x02\x12\x14\n\x10\x43\x41NNOT_SET_STATE\x10\x03\x12\x16\n\x12\x43\x41NNOT_SET_OP_MODE\x10\x04\x12\x1c\n\x18\x43\x41NNOT_SET_STATE_OP_MODE\x10\x05\x12\x0f\n\x0b\x46\x41ULT_STATE\x10\x06\x12\x11\n\rNOT_SUPPORTED\x10\x07\x12\x0f\n\x0bIN_PROGRESS\x10\x08\x12\x0b\n\x07\x41\x42ORTED\x10\t\"I\n\x0e\x43ontrollerType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08POSITION\x10\x01\x12\x0c\n\x08VELOCITY\x10\x02\x12\n\n\x06TORQUE\x10\x03\x42\x08\n\x06status\x1a\xe4\x07\n\x0fSignalGenerator\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12S\n\x07success\x18\x02 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Status.SignalGenerator.SuccessH\x00\x12S\n\x07warning\x18\x03 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Status.SignalGenerator.WarningH\x00\x12O\n\x05\x65rror\x18\x04 \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Status.SignalGenerator.ErrorH\x00\x1a\xb3\x01\n\x07Success\x12S\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x45.motionmaster.MotionMasterMessage.Status.SignalGenerator.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"B\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x12\x12\n\x0ePARAMETERS_SET\x10\x03\x1a\xa4\x01\n\x07Warning\x12S\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x45.motionmaster.MotionMasterMessage.Status.SignalGenerator.Warning.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x1a\n\x16\x41\x43\x43_DEC_VEL_CONSTRAINT\x10\x01\x1a\xd6\x02\n\x05\x45rror\x12Q\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x43.motionmaster.MotionMasterMessage.Status.SignalGenerator.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xe8\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x14\n\x10\x43\x41NNOT_GET_STATE\x10\x01\x12\x16\n\x12\x43\x41NNOT_GET_OP_MODE\x10\x02\x12\x14\n\x10\x43\x41NNOT_SET_STATE\x10\x03\x12\x16\n\x12\x43\x41NNOT_SET_OP_MODE\x10\x04\x12\x1c\n\x18\x43\x41NNOT_SET_STATE_OP_MODE\x10\x05\x12\x0f\n\x0b\x46\x41ULT_STATE\x10\x06\x12\x11\n\rNOT_SUPPORTED\x10\x07\x12\x0f\n\x0bNOT_DEFINED\x10\x08\x12\x13\n\x0f\x41LREADY_RUNNING\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\nB\x08\n\x06status\x1a\xbc\x07\n\x19MonitoringParameterValues\x12_\n\x17\x64\x65vice_parameter_values\x18\x01 \x01(\x0b\x32>.motionmaster.MotionMasterMessage.Status.DeviceParameterValues\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12]\n\x07success\x18\x03 \x01(\x0b\x32J.motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.SuccessH\x00\x12]\n\x07warning\x18\x04 \x01(\x0b\x32J.motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.WarningH\x00\x12Y\n\x05\x65rror\x18\x05 \x01(\x0b\x32H.motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.ErrorH\x00\x1a\x9c\x01\n\x07Success\x12]\n\x04\x63ode\x18\x01 \x01(\x0e\x32O.motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"!\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x1a\xaa\x01\n\x07Warning\x12]\n\x04\x63ode\x18\x01 \x01(\x0e\x32O.motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Warning.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"/\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x16\n\x12PARAMETERS_MISSING\x10\x01\x1a\xbb\x01\n\x05\x45rror\x12[\n\x04\x63ode\x18\x01 \x01(\x0e\x32M.motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"D\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07REFUSED\x10\x01\x12\x11\n\rNOT_SUPPORTED\x10\x02\x12\x0b\n\x07INVALID\x10\x03\x42\x08\n\x06status\x1a\xfe\x03\n\nDeviceStop\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12N\n\x07success\x18\x02 \x01(\x0b\x32;.motionmaster.MotionMasterMessage.Status.DeviceStop.SuccessH\x00\x12J\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x39.motionmaster.MotionMasterMessage.Status.DeviceStop.ErrorH\x00\x1a\x8d\x01\n\x07Success\x12N\n\x04\x63ode\x18\x01 \x01(\x0e\x32@.motionmaster.MotionMasterMessage.Status.DeviceStop.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"!\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x1a\xa1\x01\n\x05\x45rror\x12L\n\x04\x63ode\x18\x01 \x01(\x0e\x32>.motionmaster.MotionMasterMessage.Status.DeviceStop.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"9\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tTIMED_OUT\x10\x01\x12\x11\n\rNOT_SUPPORTED\x10\x02\x42\x08\n\x06status\x1a\xe6\x05\n\x14\x45thercatNetworkState\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12T\n\x05state\x18\x02 \x01(\x0e\x32\x43.motionmaster.MotionMasterMessage.Status.EthercatNetworkState.StateH\x00\x12X\n\x07success\x18\x03 \x01(\x0b\x32\x45.motionmaster.MotionMasterMessage.Status.EthercatNetworkState.SuccessH\x00\x12T\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x43.motionmaster.MotionMasterMessage.Status.EthercatNetworkState.ErrorH\x00\x1a\x97\x01\n\x07Success\x12X\n\x04\x63ode\x18\x01 \x01(\x0e\x32J.motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"!\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x1a\xbe\x01\n\x05\x45rror\x12V\n\x04\x63ode\x18\x01 \x01(\x0e\x32H.motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"L\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tTIMED_OUT\x10\x01\x12\x11\n\rNOT_SUPPORTED\x10\x02\x12\x11\n\rUNKNOWN_STATE\x10\x03\"K\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04INIT\x10\x01\x12\t\n\x05PREOP\x10\x02\x12\x08\n\x04\x42OOT\x10\x03\x12\n\n\x06SAFEOP\x10\x04\x12\x06\n\x02OP\x10\x05\x42\x08\n\x06status\x1a\xf1\x04\n\x16NarrowAngleCalibration\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12Z\n\x07success\x18\x02 \x01(\x0b\x32G.motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.SuccessH\x00\x12V\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x45.motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.ErrorH\x00\x1a\xa6\x01\n\x07Success\x12Z\n\x04\x63ode\x18\x01 \x01(\x0e\x32L.motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\xd7\x01\n\x05\x45rror\x12X\n\x04\x63ode\x18\x01 \x01(\x0e\x32J.motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"c\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0bINIT_FAILED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\r\n\tTIMED_OUT\x10\x04\x12\x11\n\rNOT_SUPPORTED\x10\x05\x42\x08\n\x06status\x1ap\n\x1c\x43irculoEncoderMagnetDistance\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x14\n\x0c\x65ncoder_port\x18\x02 \x01(\r\x12\x10\n\x08\x64istance\x18\x03 \x01(\x02\x12\x10\n\x08position\x18\x04 \x01(\x12\x1a\x8f\x06\n-CirculoEncoderNarrowAngleCalibrationProcedure\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12\x14\n\x0c\x65ncoder_port\x18\x02 \x01(\r\x12q\n\x07success\x18\x03 \x01(\x0b\x32^.motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.SuccessH\x00\x12m\n\x05\x65rror\x18\x04 \x01(\x0b\x32\\.motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.ErrorH\x00\x1a\xbd\x01\n\x07Success\x12q\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x63.motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\x83\x02\n\x05\x45rror\x12o\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x61.motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"x\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0bINIT_FAILED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\r\n\tTIMED_OUT\x10\x04\x12\x11\n\rNOT_SUPPORTED\x10\x05\x12\x13\n\x0f\x41LREADY_RUNNING\x10\x06\x42\x08\n\x06status\x1a\xe0\x06\n\x11\x44\x65viceCiA402State\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\r\x12Q\n\x05state\x18\x02 \x01(\x0e\x32@.motionmaster.MotionMasterMessage.Status.DeviceCiA402State.StateH\x00\x12U\n\x07success\x18\x03 \x01(\x0b\x32\x42.motionmaster.MotionMasterMessage.Status.DeviceCiA402State.SuccessH\x00\x12Q\n\x05\x65rror\x18\x04 \x01(\x0b\x32@.motionmaster.MotionMasterMessage.Status.DeviceCiA402State.ErrorH\x00\x1a\x94\x01\n\x07Success\x12U\n\x04\x63ode\x18\x01 \x01(\x0e\x32G.motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"!\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x1a\xdf\x01\n\x05\x45rror\x12S\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x45.motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"p\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tTIMED_OUT\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\t\n\x05\x46\x41ULT\x10\x03\x12\x11\n\rNOT_SUPPORTED\x10\x04\x12\x11\n\rUNKNOWN_STATE\x10\x05\x12\x0b\n\x07\x41\x42ORTED\x10\x06\"\xb2\x01\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tNOT_READY\x10\x01\x12\x16\n\x12SWITCH_ON_DISABLED\x10\x02\x12\x13\n\x0fREADY_SWITCH_ON\x10\x03\x12\x0f\n\x0bSWITCHED_ON\x10\x04\x12\x0e\n\nOP_ENABLED\x10\x05\x12\x15\n\x11QUICK_STOP_ACTIVE\x10\x06\x12\x19\n\x15\x46\x41ULT_REACTION_ACTIVE\x10\x07\x12\t\n\x05\x46\x41ULT\x10\x08\x42\x08\n\x06status\x1a-\n\tSystemLog\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0f\n\x07run_env\x18\x02 \x01(\t\x1a\xe7\x04\n\x10\x44\x65viceSiiRestore\x12\x17\n\x0f\x64\x65vice_position\x18\x01 \x01(\r\x12T\n\x07success\x18\x02 \x01(\x0b\x32\x41.motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.SuccessH\x00\x12P\n\x05\x65rror\x18\x03 \x01(\x0b\x32?.motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.ErrorH\x00\x1a\xa0\x01\n\x07Success\x12T\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x46.motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Success.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\".\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\x08\n\x04\x44ONE\x10\x02\x1a\xe4\x01\n\x05\x45rror\x12R\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x44.motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Error.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"v\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x11\n\rSII_CORRUPTED\x10\x01\x12\x0b\n\x07REFUSED\x10\x02\x12\x11\n\rNOT_SUPPORTED\x10\x03\x12\x14\n\x10SII_WRITE_FAILED\x10\x04\x12\x14\n\x10\x44\x45VICE_NOT_FOUND\x10\x05\x42\x08\n\x06statusB\x06\n\x04typeJ\x04\x08\x01\x10\x65J\x06\x08\x83\x01\x10\xe9\x07\x42\x06\n\x04typeJ\x04\x08\x02\x10\x65J\x05\x08g\x10\xe9\x07\x42\x1f\n\x1b\x63om.synapticon.motionmasterH\x01\x62\x06proto3'
)



_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS_CONTROLLERTYPE = _descriptor.EnumDescriptor(
  name='ControllerType',
  full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.ControllerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PI_P', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='P_PI', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6824,
  serialized_end=6877,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS_CONTROLLERTYPE)

_MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER_CONTROLLERTYPE = _descriptor.EnumDescriptor(
  name='ControllerType',
  full_name='motionmaster.MotionMasterMessage.Request.EnableMotionController.ControllerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSITION', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TORQUE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7214,
  serialized_end=7287,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER_CONTROLLERTYPE)

_MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='motionmaster.MotionMasterMessage.Request.SetEthercatNetworkState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREOP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAFEOP', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OP', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12361,
  serialized_end=12436,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE_STATE)

_MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='motionmaster.MotionMasterMessage.Request.SetDeviceCiA402State.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWITCH_ON_DISABLED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY_SWITCH_ON', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWITCHED_ON', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OP_ENABLED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUICK_STOP_ACTIVE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAULT_REACTION_ACTIVE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAULT', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12903,
  serialized_end=13081,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE_STATE)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Info.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SLAVE_NUMBER_CHANGED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16543,
  serialized_end=16592,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO_CODE)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16543,
  serialized_end=16566,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Warning.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DROPPING_CONNECTION', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16839,
  serialized_end=16887,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING_CODE)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_MESSAGE_TYPE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_DETECT_SLAVES', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DEVICE_ADDRESS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONFIGURATION_RELOAD_FAILED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16996,
  serialized_end=17132,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WAITING_FOR_SLAVES', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SLAVES_FOUND', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEINITIALIZING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEINITIALIZED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TERMINATING', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17135,
  serialized_end=17292,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_STATE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo.Device.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOMANET_CIA401_ETHERCAT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOMANET_CIA402_ETHERCAT', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=17543,
  serialized_end=17624,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE_TYPE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER_VALUETYPE = _descriptor.EnumDescriptor(
  name='ValueType',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.ValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER8', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER16', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER32', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSIGNED8', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSIGNED16', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSIGNED32', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REAL32', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VISIBLE_STRING', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OCTET_STRING', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNICODE_STRING', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME_OF_DAY', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=18028,
  serialized_end=18247,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER_VALUETYPE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19001,
  serialized_end=19047,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REFRESH_VALUE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_CHANGED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19180,
  serialized_end=19261,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19796,
  serialized_end=19838,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20185,
  serialized_end=20230,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=20337,
  serialized_end=20406,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PACKAGE_CORRUPTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SII_CORRUPTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_NOT_FOUND', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REFUSED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SII_WRITE_FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE_WRITE_FAILED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE_DELETE_FAILED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_NOT_FOUND', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21579,
  serialized_end=21788,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22085,
  serialized_end=22142,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19001,
  serialized_end=19034,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Warning.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_FAULT', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22716,
  serialized_end=22753,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=22866,
  serialized_end=22935,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_HALL_SENSOR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_RESOLUTION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_COMMUTATION_SENSOR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_COMMUTATION_AND_MOTION_SENSOR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSITION_CONTROLLER_NOT_TUNED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAVING_FAILED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAVING_ABORTED', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAVING_TIMEOUT', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_POSITION_CONTROL_FUNCTION', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=23465,
  serialized_end=23803,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CORRUPTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24162,
  serialized_end=24234,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_FAILED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=24726,
  serialized_end=24823,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_POSITION_CONTROL_SENSOR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZERO_TORQUE_AMPLITUDE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZERO_VELOCITY_AMPLITUDE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRONG_SENSOR_POLARITY', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALL_MOTION_AMPLITUDE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25338,
  serialized_end=25580,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_POSITION_CONTROL_SENSOR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZERO_TORQUE_AMPLITUDE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZERO_VELOCITY_AMPLITUDE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRONG_SENSOR_POLARITY', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALL_MOTION_AMPLITUDE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=25338,
  serialized_end=25580,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSITION_STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSITION_DONE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY_STARTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY_DONE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=26738,
  serialized_end=26843,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Warning.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SETTLING_TIME_NOT_REACHED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY_UNSTABLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALL_VELOCITY_AMPLITUDE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=26954,
  serialized_end=27061,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING_CODE)

_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLANT_MODEL_INVALID', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLANT_MODEL_NOT_FOUND', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ACHIEVE_SETTLING_TIME', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSITION_FAILED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY_FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=27169,
  serialized_end=27339,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.MotionController.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19001,
  serialized_end=19034,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.MotionController.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_GET_STATE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_GET_OP_MODE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_STATE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_OP_MODE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_STATE_OP_MODE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAULT_STATE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=27958,
  serialized_end=28169,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_CONTROLLERTYPE = _descriptor.EnumDescriptor(
  name='ControllerType',
  full_name='motionmaster.MotionMasterMessage.Status.MotionController.ControllerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POSITION', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TORQUE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7214,
  serialized_end=7287,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_CONTROLLERTYPE)

_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARAMETERS_SET', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=28665,
  serialized_end=28731,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Warning.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACC_DEC_VEL_CONSTRAINT', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=28847,
  serialized_end=28898,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING_CODE)

_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_GET_STATE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_GET_OP_MODE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_STATE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_OP_MODE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_SET_STATE_OP_MODE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAULT_STATE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_DEFINED', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_RUNNING', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29011,
  serialized_end=29243,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19001,
  serialized_end=19034,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Warning.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARAMETERS_MISSING', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=29965,
  serialized_end=30012,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING_CODE)

_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REFUSED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=30134,
  serialized_end=30202,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19001,
  serialized_end=19034,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=30658,
  serialized_end=30715,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19001,
  serialized_end=19034,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_STATE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=31307,
  serialized_end=31383,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREOP', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAFEOP', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OP', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12361,
  serialized_end=12436,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_STATE)

_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_FAILED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=31989,
  serialized_end=32088,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT_FAILED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_RUNNING', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=32868,
  serialized_end=32988,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=19001,
  serialized_end=19034,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMED_OUT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAULT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_STATE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=33562,
  serialized_end=33674,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWITCH_ON_DISABLED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY_SWITCH_ON', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SWITCHED_ON', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OP_ENABLED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUICK_STOP_ACTIVE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAULT_REACTION_ACTIVE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAULT', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12903,
  serialized_end=13081,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_STATE)

_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Success.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=21409,
  serialized_end=21455,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS_CODE)

_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Error.Code',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SII_CORRUPTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REFUSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SII_WRITE_FAILED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_NOT_FOUND', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=34402,
  serialized_end=34520,
)
_sym_db.RegisterEnumDescriptor(_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR_CODE)


_MOTIONMASTERMESSAGE_REQUEST_PINGSYSTEM = _descriptor.Descriptor(
  name='PingSystem',
  full_name='motionmaster.MotionMasterMessage.Request.PingSystem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4384,
  serialized_end=4396,
)

_MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMVERSION = _descriptor.Descriptor(
  name='GetSystemVersion',
  full_name='motionmaster.MotionMasterMessage.Request.GetSystemVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4398,
  serialized_end=4416,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEINFO = _descriptor.Descriptor(
  name='GetDeviceInfo',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4418,
  serialized_end=4433,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERINFO = _descriptor.Descriptor(
  name='GetDeviceParameterInfo',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterInfo.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4435,
  serialized_end=4483,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.Parameter.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subindex', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.Parameter.subindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='load_from_cache', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.Parameter.load_from_cache', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4659,
  serialized_end=4728,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='GetDeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.parameters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_progress', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.send_progress', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES_PARAMETER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4486,
  serialized_end=4728,
)

_MOTIONMASTERMESSAGE_REQUEST_GETMULTIDEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='GetMultiDeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Request.GetMultiDeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection', full_name='motionmaster.MotionMasterMessage.Request.GetMultiDeviceParameterValues.collection', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4730,
  serialized_end=4849,
)

_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE = _descriptor.Descriptor(
  name='ParameterValue',
  full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subindex', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.subindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.int_value', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint_value', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.uint_value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.float_value', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_value', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.raw_value', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type_value', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue.type_value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5014,
  serialized_end=5188,
)

_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='SetDeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_values', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.parameter_values', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4852,
  serialized_end=5188,
)

_MOTIONMASTERMESSAGE_REQUEST_SETMULTIDEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='SetMultiDeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Request.SetMultiDeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection', full_name='motionmaster.MotionMasterMessage.Request.SetMultiDeviceParameterValues.collection', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5190,
  serialized_end=5309,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILELIST = _descriptor.Descriptor(
  name='GetDeviceFileList',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceFileList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceFileList.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5311,
  serialized_end=5354,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILE = _descriptor.Descriptor(
  name='GetDeviceFile',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceFile.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceFile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5356,
  serialized_end=5409,
)

_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEFILE = _descriptor.Descriptor(
  name='SetDeviceFile',
  full_name='motionmaster.MotionMasterMessage.Request.SetDeviceFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceFile.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceFile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceFile.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceFile.overwrite', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5411,
  serialized_end=5500,
)

_MOTIONMASTERMESSAGE_REQUEST_DELETEDEVICEFILE = _descriptor.Descriptor(
  name='DeleteDeviceFile',
  full_name='motionmaster.MotionMasterMessage.Request.DeleteDeviceFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.DeleteDeviceFile.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='motionmaster.MotionMasterMessage.Request.DeleteDeviceFile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5502,
  serialized_end=5558,
)

_MOTIONMASTERMESSAGE_REQUEST_RESETDEVICEFAULT = _descriptor.Descriptor(
  name='ResetDeviceFault',
  full_name='motionmaster.MotionMasterMessage.Request.ResetDeviceFault',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.ResetDeviceFault.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5560,
  serialized_end=5602,
)

_MOTIONMASTERMESSAGE_REQUEST_STOPDEVICE = _descriptor.Descriptor(
  name='StopDevice',
  full_name='motionmaster.MotionMasterMessage.Request.StopDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StopDevice.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5604,
  serialized_end=5640,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTDEVICEFIRMWAREINSTALLATION = _descriptor.Descriptor(
  name='StartDeviceFirmwareInstallation',
  full_name='motionmaster.MotionMasterMessage.Request.StartDeviceFirmwareInstallation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartDeviceFirmwareInstallation.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firmware_package_content', full_name='motionmaster.MotionMasterMessage.Request.StartDeviceFirmwareInstallation.firmware_package_content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5642,
  serialized_end=5733,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICELOG = _descriptor.Descriptor(
  name='GetDeviceLog',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceLog.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5735,
  serialized_end=5773,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTCOGGINGTORQUERECORDING = _descriptor.Descriptor(
  name='StartCoggingTorqueRecording',
  full_name='motionmaster.MotionMasterMessage.Request.StartCoggingTorqueRecording',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartCoggingTorqueRecording.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skip_auto_tuning', full_name='motionmaster.MotionMasterMessage.Request.StartCoggingTorqueRecording.skip_auto_tuning', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5775,
  serialized_end=5854,
)

_MOTIONMASTERMESSAGE_REQUEST_GETCOGGINGTORQUEDATA = _descriptor.Descriptor(
  name='GetCoggingTorqueData',
  full_name='motionmaster.MotionMasterMessage.Request.GetCoggingTorqueData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetCoggingTorqueData.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5856,
  serialized_end=5902,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTOFFSETDETECTION = _descriptor.Descriptor(
  name='StartOffsetDetection',
  full_name='motionmaster.MotionMasterMessage.Request.StartOffsetDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartOffsetDetection.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5904,
  serialized_end=5950,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTPLANTIDENTIFICATION = _descriptor.Descriptor(
  name='StartPlantIdentification',
  full_name='motionmaster.MotionMasterMessage.Request.StartPlantIdentification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartPlantIdentification.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_seconds', full_name='motionmaster.MotionMasterMessage.Request.StartPlantIdentification.duration_seconds', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_amplitude', full_name='motionmaster.MotionMasterMessage.Request.StartPlantIdentification.torque_amplitude', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_frequency', full_name='motionmaster.MotionMasterMessage.Request.StartPlantIdentification.start_frequency', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_frequency', full_name='motionmaster.MotionMasterMessage.Request.StartPlantIdentification.end_frequency', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cutoff_frequency', full_name='motionmaster.MotionMasterMessage.Request.StartPlantIdentification.cutoff_frequency', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5953,
  serialized_end=6129,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTSYSTEMIDENTIFICATION = _descriptor.Descriptor(
  name='StartSystemIdentification',
  full_name='motionmaster.MotionMasterMessage.Request.StartSystemIdentification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartSystemIdentification.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_seconds', full_name='motionmaster.MotionMasterMessage.Request.StartSystemIdentification.duration_seconds', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_amplitude', full_name='motionmaster.MotionMasterMessage.Request.StartSystemIdentification.torque_amplitude', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_frequency', full_name='motionmaster.MotionMasterMessage.Request.StartSystemIdentification.start_frequency', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_frequency', full_name='motionmaster.MotionMasterMessage.Request.StartSystemIdentification.end_frequency', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6132,
  serialized_end=6283,
)

_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS = _descriptor.Descriptor(
  name='PositionParameters',
  full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller_type', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.controller_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settling_time', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.settling_time', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_damping', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.position_damping', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alpha_mult', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.alpha_mult', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.order', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lb', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.lb', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ub', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters.ub', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS_CONTROLLERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6569,
  serialized_end=6877,
)

_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_VELOCITYPARAMETERS = _descriptor.Descriptor(
  name='VelocityParameters',
  full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.VelocityParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='velocity_loop_bandwidth', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.VelocityParameters.velocity_loop_bandwidth', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_damping', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.VelocityParameters.velocity_damping', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6879,
  serialized_end=6958,
)

_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS = _descriptor.Descriptor(
  name='ComputeAutoTuningGains',
  full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_parameters', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.position_parameters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_parameters', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.velocity_parameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS, _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_VELOCITYPARAMETERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6286,
  serialized_end=6966,
)

_MOTIONMASTERMESSAGE_REQUEST_SETMOTIONCONTROLLERPARAMETERS = _descriptor.Descriptor(
  name='SetMotionControllerParameters',
  full_name='motionmaster.MotionMasterMessage.Request.SetMotionControllerParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.SetMotionControllerParameters.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetMotionControllerParameters.target', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6968,
  serialized_end=7039,
)

_MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER = _descriptor.Descriptor(
  name='EnableMotionController',
  full_name='motionmaster.MotionMasterMessage.Request.EnableMotionController',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.EnableMotionController.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_type', full_name='motionmaster.MotionMasterMessage.Request.EnableMotionController.controller_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='motionmaster.MotionMasterMessage.Request.EnableMotionController.filter', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER_CONTROLLERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7042,
  serialized_end=7287,
)

_MOTIONMASTERMESSAGE_REQUEST_DISABLEMOTIONCONTROLLER = _descriptor.Descriptor(
  name='DisableMotionController',
  full_name='motionmaster.MotionMasterMessage.Request.DisableMotionController',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.DisableMotionController.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7289,
  serialized_end=7338,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSTEPRESPONSE = _descriptor.Descriptor(
  name='PositionStepResponse',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionStepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionStepResponse.target', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionStepResponse.sustain_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionStepResponse.absolute_target', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9632,
  serialized_end=9717,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONADVANCEDSTEPRESPONSE = _descriptor.Descriptor(
  name='PositionAdvancedStepResponse',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponse.target', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponse.sustain_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponse.repeat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponse.absolute_target', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9719,
  serialized_end=9828,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONRAMP = _descriptor.Descriptor(
  name='PositionRamp',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp.target', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_velocity', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp.profile_velocity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_acceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp.profile_acceleration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_deceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp.profile_deceleration', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp.sustain_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp.master_generated', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp.absolute_target', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9831,
  serialized_end=10020,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONTRAPEZOIDAL = _descriptor.Descriptor(
  name='PositionTrapezoidal',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.target', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_velocity', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.profile_velocity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_acceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.profile_acceleration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_deceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.profile_deceleration', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.sustain_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.repeat', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.master_generated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal.absolute_target', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10023,
  serialized_end=10235,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONBIDIRECTIONAL = _descriptor.Descriptor(
  name='PositionBidirectional',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.target', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_velocity', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.profile_velocity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_acceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.profile_acceleration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_deceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.profile_deceleration', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.sustain_time', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.repeat', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.master_generated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional.absolute_target', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10238,
  serialized_end=10452,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSINEWAVE = _descriptor.Descriptor(
  name='PositionSineWave',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWave.amplitude', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWave.frequency', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWave.repeat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absolute_target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWave.absolute_target', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10454,
  serialized_end=10551,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSTEPRESPONSE = _descriptor.Descriptor(
  name='VelocityStepResponse',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityStepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityStepResponse.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityStepResponse.sustain_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10553,
  serialized_end=10613,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYADVANCEDSTEPRESPONSE = _descriptor.Descriptor(
  name='VelocityAdvancedStepResponse',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityAdvancedStepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityAdvancedStepResponse.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityAdvancedStepResponse.sustain_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityAdvancedStepResponse.repeat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10615,
  serialized_end=10699,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYRAMP = _descriptor.Descriptor(
  name='VelocityRamp',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_acceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp.profile_acceleration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_deceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp.profile_deceleration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp.sustain_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp.master_generated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10702,
  serialized_end=10840,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYTRAPEZOIDAL = _descriptor.Descriptor(
  name='VelocityTrapezoidal',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_acceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal.profile_acceleration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_deceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal.profile_deceleration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal.sustain_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal.repeat', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal.master_generated', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10843,
  serialized_end=11004,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYBIDIRECTIONAL = _descriptor.Descriptor(
  name='VelocityBidirectional',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_acceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional.profile_acceleration', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='profile_deceleration', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional.profile_deceleration', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional.sustain_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional.repeat', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional.master_generated', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11007,
  serialized_end=11170,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSINEWAVE = _descriptor.Descriptor(
  name='VelocitySineWave',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocitySineWave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocitySineWave.amplitude', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocitySineWave.frequency', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocitySineWave.repeat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11172,
  serialized_end=11244,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESTEPRESPONSE = _descriptor.Descriptor(
  name='TorqueStepResponse',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueStepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueStepResponse.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueStepResponse.sustain_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11246,
  serialized_end=11304,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEADVANCEDSTEPRESPONSE = _descriptor.Descriptor(
  name='TorqueAdvancedStepResponse',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueAdvancedStepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueAdvancedStepResponse.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueAdvancedStepResponse.sustain_time', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueAdvancedStepResponse.repeat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11306,
  serialized_end=11388,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUERAMP = _descriptor.Descriptor(
  name='TorqueRamp',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRamp.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_slope', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRamp.torque_slope', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRamp.sustain_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRamp.master_generated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11390,
  serialized_end=11488,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUETRAPEZOIDAL = _descriptor.Descriptor(
  name='TorqueTrapezoidal',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_slope', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal.torque_slope', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal.sustain_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal.repeat', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal.master_generated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11490,
  serialized_end=11611,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEBIDIRECTIONAL = _descriptor.Descriptor(
  name='TorqueBidirectional',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional.target', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_slope', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional.torque_slope', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sustain_time', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional.sustain_time', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional.repeat', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_generated', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional.master_generated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11613,
  serialized_end=11736,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESINEWAVE = _descriptor.Descriptor(
  name='TorqueSineWave',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueSineWave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amplitude', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueSineWave.amplitude', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueSineWave.frequency', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueSineWave.repeat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11738,
  serialized_end=11808,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS = _descriptor.Descriptor(
  name='SetSignalGeneratorParameters',
  full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_step_response', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.position_step_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_advanced_step_response', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.position_advanced_step_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_ramp', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.position_ramp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_trapezoidal', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.position_trapezoidal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_bidirectional', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.position_bidirectional', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position_sine_wave', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.position_sine_wave', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_step_response', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.velocity_step_response', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_advanced_step_response', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.velocity_advanced_step_response', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_ramp', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.velocity_ramp', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_trapezoidal', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.velocity_trapezoidal', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_bidirectional', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.velocity_bidirectional', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='velocity_sine_wave', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.velocity_sine_wave', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_step_response', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.torque_step_response', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_advanced_step_response', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.torque_advanced_step_response', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_ramp', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.torque_ramp', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_trapezoidal', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.torque_trapezoidal', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_bidirectional', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.torque_bidirectional', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='torque_sine_wave', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.torque_sine_wave', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSTEPRESPONSE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONADVANCEDSTEPRESPONSE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONRAMP, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONTRAPEZOIDAL, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONBIDIRECTIONAL, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSINEWAVE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSTEPRESPONSE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYADVANCEDSTEPRESPONSE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYRAMP, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYTRAPEZOIDAL, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYBIDIRECTIONAL, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSINEWAVE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESTEPRESPONSE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEADVANCEDSTEPRESPONSE, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUERAMP, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUETRAPEZOIDAL, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEBIDIRECTIONAL, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESINEWAVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='signal', full_name='motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.signal',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=7341,
  serialized_end=11818,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTSIGNALGENERATOR = _descriptor.Descriptor(
  name='StartSignalGenerator',
  full_name='motionmaster.MotionMasterMessage.Request.StartSignalGenerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartSignalGenerator.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11820,
  serialized_end=11866,
)

_MOTIONMASTERMESSAGE_REQUEST_STOPSIGNALGENERATOR = _descriptor.Descriptor(
  name='StopSignalGenerator',
  full_name='motionmaster.MotionMasterMessage.Request.StopSignalGenerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StopSignalGenerator.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11868,
  serialized_end=11913,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTMONITORINGDEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='StartMonitoringDeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Request.StartMonitoringDeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Request.StartMonitoringDeviceParameterValues.get_device_parameter_values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='motionmaster.MotionMasterMessage.Request.StartMonitoringDeviceParameterValues.interval', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='motionmaster.MotionMasterMessage.Request.StartMonitoringDeviceParameterValues.topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11916,
  serialized_end=12092,
)

_MOTIONMASTERMESSAGE_REQUEST_STOPMONITORINGDEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='StopMonitoringDeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Request.StopMonitoringDeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_monitoring_request_id', full_name='motionmaster.MotionMasterMessage.Request.StopMonitoringDeviceParameterValues.start_monitoring_request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12094,
  serialized_end=12168,
)

_MOTIONMASTERMESSAGE_REQUEST_GETETHERCATNETWORKSTATE = _descriptor.Descriptor(
  name='GetEthercatNetworkState',
  full_name='motionmaster.MotionMasterMessage.Request.GetEthercatNetworkState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetEthercatNetworkState.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12170,
  serialized_end=12219,
)

_MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE = _descriptor.Descriptor(
  name='SetEthercatNetworkState',
  full_name='motionmaster.MotionMasterMessage.Request.SetEthercatNetworkState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.SetEthercatNetworkState.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='motionmaster.MotionMasterMessage.Request.SetEthercatNetworkState.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12222,
  serialized_end=12436,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTNARROWANGLECALIBRATION = _descriptor.Descriptor(
  name='StartNarrowAngleCalibration',
  full_name='motionmaster.MotionMasterMessage.Request.StartNarrowAngleCalibration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartNarrowAngleCalibration.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12438,
  serialized_end=12491,
)

_MOTIONMASTERMESSAGE_REQUEST_SETSYSTEMCLIENTTIMEOUT = _descriptor.Descriptor(
  name='SetSystemClientTimeout',
  full_name='motionmaster.MotionMasterMessage.Request.SetSystemClientTimeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout_ms', full_name='motionmaster.MotionMasterMessage.Request.SetSystemClientTimeout.timeout_ms', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12493,
  serialized_end=12537,
)

_MOTIONMASTERMESSAGE_REQUEST_GETCIRCULOENCODERMAGNETDISTANCE = _descriptor.Descriptor(
  name='GetCirculoEncoderMagnetDistance',
  full_name='motionmaster.MotionMasterMessage.Request.GetCirculoEncoderMagnetDistance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetCirculoEncoderMagnetDistance.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoder_port', full_name='motionmaster.MotionMasterMessage.Request.GetCirculoEncoderMagnetDistance.encoder_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12539,
  serialized_end=12618,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTCIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE = _descriptor.Descriptor(
  name='StartCirculoEncoderNarrowAngleCalibrationProcedure',
  full_name='motionmaster.MotionMasterMessage.Request.StartCirculoEncoderNarrowAngleCalibrationProcedure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.StartCirculoEncoderNarrowAngleCalibrationProcedure.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoder_port', full_name='motionmaster.MotionMasterMessage.Request.StartCirculoEncoderNarrowAngleCalibrationProcedure.encoder_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12620,
  serialized_end=12718,
)

_MOTIONMASTERMESSAGE_REQUEST_GETDEVICECIA402STATE = _descriptor.Descriptor(
  name='GetDeviceCiA402State',
  full_name='motionmaster.MotionMasterMessage.Request.GetDeviceCiA402State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.GetDeviceCiA402State.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12720,
  serialized_end=12766,
)

_MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE = _descriptor.Descriptor(
  name='SetDeviceCiA402State',
  full_name='motionmaster.MotionMasterMessage.Request.SetDeviceCiA402State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceCiA402State.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='motionmaster.MotionMasterMessage.Request.SetDeviceCiA402State.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12769,
  serialized_end=13081,
)

_MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMLOG = _descriptor.Descriptor(
  name='GetSystemLog',
  full_name='motionmaster.MotionMasterMessage.Request.GetSystemLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13083,
  serialized_end=13097,
)

_MOTIONMASTERMESSAGE_REQUEST_STARTDEVICESIIRESTORE = _descriptor.Descriptor(
  name='StartDeviceSiiRestore',
  full_name='motionmaster.MotionMasterMessage.Request.StartDeviceSiiRestore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_position', full_name='motionmaster.MotionMasterMessage.Request.StartDeviceSiiRestore.device_position', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sii_content', full_name='motionmaster.MotionMasterMessage.Request.StartDeviceSiiRestore.sii_content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13099,
  serialized_end=13168,
)

_MOTIONMASTERMESSAGE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='motionmaster.MotionMasterMessage.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='motionmaster.MotionMasterMessage.Request.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ping_system', full_name='motionmaster.MotionMasterMessage.Request.ping_system', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_system_version', full_name='motionmaster.MotionMasterMessage.Request.get_system_version', index=2,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_device_info', full_name='motionmaster.MotionMasterMessage.Request.get_device_info', index=3,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_device_parameter_info', full_name='motionmaster.MotionMasterMessage.Request.get_device_parameter_info', index=4,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Request.get_device_parameter_values', index=5,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_multi_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Request.get_multi_device_parameter_values', index=6,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Request.set_device_parameter_values', index=7,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_multi_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Request.set_multi_device_parameter_values', index=8,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_device_file_list', full_name='motionmaster.MotionMasterMessage.Request.get_device_file_list', index=9,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_device_file', full_name='motionmaster.MotionMasterMessage.Request.get_device_file', index=10,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_device_file', full_name='motionmaster.MotionMasterMessage.Request.set_device_file', index=11,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_device_file', full_name='motionmaster.MotionMasterMessage.Request.delete_device_file', index=12,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reset_device_fault', full_name='motionmaster.MotionMasterMessage.Request.reset_device_fault', index=13,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_device', full_name='motionmaster.MotionMasterMessage.Request.stop_device', index=14,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_device_firmware_installation', full_name='motionmaster.MotionMasterMessage.Request.start_device_firmware_installation', index=15,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_device_log', full_name='motionmaster.MotionMasterMessage.Request.get_device_log', index=16,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_cogging_torque_recording', full_name='motionmaster.MotionMasterMessage.Request.start_cogging_torque_recording', index=17,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_cogging_torque_data', full_name='motionmaster.MotionMasterMessage.Request.get_cogging_torque_data', index=18,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_offset_detection', full_name='motionmaster.MotionMasterMessage.Request.start_offset_detection', index=19,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_plant_identification', full_name='motionmaster.MotionMasterMessage.Request.start_plant_identification', index=20,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compute_auto_tuning_gains', full_name='motionmaster.MotionMasterMessage.Request.compute_auto_tuning_gains', index=21,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_motion_controller_parameters', full_name='motionmaster.MotionMasterMessage.Request.set_motion_controller_parameters', index=22,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_motion_controller', full_name='motionmaster.MotionMasterMessage.Request.enable_motion_controller', index=23,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_motion_controller', full_name='motionmaster.MotionMasterMessage.Request.disable_motion_controller', index=24,
      number=124, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_signal_generator_parameters', full_name='motionmaster.MotionMasterMessage.Request.set_signal_generator_parameters', index=25,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_signal_generator', full_name='motionmaster.MotionMasterMessage.Request.start_signal_generator', index=26,
      number=126, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_signal_generator', full_name='motionmaster.MotionMasterMessage.Request.stop_signal_generator', index=27,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_monitoring_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Request.start_monitoring_device_parameter_values', index=28,
      number=128, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_monitoring_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Request.stop_monitoring_device_parameter_values', index=29,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_ethercat_network_state', full_name='motionmaster.MotionMasterMessage.Request.get_ethercat_network_state', index=30,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_ethercat_network_state', full_name='motionmaster.MotionMasterMessage.Request.set_ethercat_network_state', index=31,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_narrow_angle_calibration', full_name='motionmaster.MotionMasterMessage.Request.start_narrow_angle_calibration', index=32,
      number=132, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_system_client_timeout', full_name='motionmaster.MotionMasterMessage.Request.set_system_client_timeout', index=33,
      number=133, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_system_identification', full_name='motionmaster.MotionMasterMessage.Request.start_system_identification', index=34,
      number=134, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_circulo_encoder_magnet_distance', full_name='motionmaster.MotionMasterMessage.Request.get_circulo_encoder_magnet_distance', index=35,
      number=135, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_circulo_encoder_narrow_angle_calibration_procedure', full_name='motionmaster.MotionMasterMessage.Request.start_circulo_encoder_narrow_angle_calibration_procedure', index=36,
      number=136, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_device_cia402_state', full_name='motionmaster.MotionMasterMessage.Request.get_device_cia402_state', index=37,
      number=137, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_device_cia402_state', full_name='motionmaster.MotionMasterMessage.Request.set_device_cia402_state', index=38,
      number=138, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_system_log', full_name='motionmaster.MotionMasterMessage.Request.get_system_log', index=39,
      number=139, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_device_sii_restore', full_name='motionmaster.MotionMasterMessage.Request.start_device_sii_restore', index=40,
      number=140, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_REQUEST_PINGSYSTEM, _MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMVERSION, _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEINFO, _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERINFO, _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_REQUEST_GETMULTIDEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_REQUEST_SETMULTIDEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILELIST, _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILE, _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEFILE, _MOTIONMASTERMESSAGE_REQUEST_DELETEDEVICEFILE, _MOTIONMASTERMESSAGE_REQUEST_RESETDEVICEFAULT, _MOTIONMASTERMESSAGE_REQUEST_STOPDEVICE, _MOTIONMASTERMESSAGE_REQUEST_STARTDEVICEFIRMWAREINSTALLATION, _MOTIONMASTERMESSAGE_REQUEST_GETDEVICELOG, _MOTIONMASTERMESSAGE_REQUEST_STARTCOGGINGTORQUERECORDING, _MOTIONMASTERMESSAGE_REQUEST_GETCOGGINGTORQUEDATA, _MOTIONMASTERMESSAGE_REQUEST_STARTOFFSETDETECTION, _MOTIONMASTERMESSAGE_REQUEST_STARTPLANTIDENTIFICATION, _MOTIONMASTERMESSAGE_REQUEST_STARTSYSTEMIDENTIFICATION, _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS, _MOTIONMASTERMESSAGE_REQUEST_SETMOTIONCONTROLLERPARAMETERS, _MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER, _MOTIONMASTERMESSAGE_REQUEST_DISABLEMOTIONCONTROLLER, _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS, _MOTIONMASTERMESSAGE_REQUEST_STARTSIGNALGENERATOR, _MOTIONMASTERMESSAGE_REQUEST_STOPSIGNALGENERATOR, _MOTIONMASTERMESSAGE_REQUEST_STARTMONITORINGDEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_REQUEST_STOPMONITORINGDEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_REQUEST_GETETHERCATNETWORKSTATE, _MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE, _MOTIONMASTERMESSAGE_REQUEST_STARTNARROWANGLECALIBRATION, _MOTIONMASTERMESSAGE_REQUEST_SETSYSTEMCLIENTTIMEOUT, _MOTIONMASTERMESSAGE_REQUEST_GETCIRCULOENCODERMAGNETDISTANCE, _MOTIONMASTERMESSAGE_REQUEST_STARTCIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE, _MOTIONMASTERMESSAGE_REQUEST_GETDEVICECIA402STATE, _MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE, _MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMLOG, _MOTIONMASTERMESSAGE_REQUEST_STARTDEVICESIIRESTORE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='motionmaster.MotionMasterMessage.Request.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=197,
  serialized_end=13190,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMPONG = _descriptor.Descriptor(
  name='SystemPong',
  full_name='motionmaster.MotionMasterMessage.Status.SystemPong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15960,
  serialized_end=15972,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMVERSION = _descriptor.Descriptor(
  name='SystemVersion',
  full_name='motionmaster.MotionMasterMessage.Status.SystemVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='motionmaster.MotionMasterMessage.Status.SystemVersion.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15974,
  serialized_end=16006,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO = _descriptor.Descriptor(
  name='Info',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Info.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Info.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16440,
  serialized_end=16592,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16595,
  serialized_end=16727,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING = _descriptor.Descriptor(
  name='Warning',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Warning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Warning.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Warning.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16730,
  serialized_end=16887,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16890,
  serialized_end=17132,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT = _descriptor.Descriptor(
  name='SystemEvent',
  full_name='motionmaster.MotionMasterMessage.Status.SystemEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.success', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.warning', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.error', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO, _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING, _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR, ],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.SystemEvent.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=16009,
  serialized_end=17302,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo.Device.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo.Device.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo.Device.position', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo.Device.alias', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17397,
  serialized_end=17624,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO = _descriptor.Descriptor(
  name='DeviceInfo',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='motionmaster.MotionMasterMessage.Status.DeviceInfo.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17305,
  serialized_end=17624,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER = _descriptor.Descriptor(
  name='Parameter',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subindex', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.subindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_access', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.read_access', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='write_access', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.write_access', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.min', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.max', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter.value_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER_VALUETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17767,
  serialized_end=18247,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO = _descriptor.Descriptor(
  name='DeviceParameterInfo',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.parameters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17627,
  serialized_end=18247,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18867,
  serialized_end=19047,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19050,
  serialized_end=19261,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE = _descriptor.Descriptor(
  name='ParameterValue',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subindex', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.subindex', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.int_value', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint_value', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.uint_value', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.float_value', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_value', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.raw_value', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.success', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.error', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type_value', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.type_value',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.status',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=18496,
  serialized_end=19285,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentage', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.Progress.percentage', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.Progress.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19287,
  serialized_end=19334,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='DeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter_values', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.parameter_values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='progress', full_name='motionmaster.MotionMasterMessage.Status.DeviceParameterValues.progress', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE, _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PROGRESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18250,
  serialized_end=19334,
)

_MOTIONMASTERMESSAGE_STATUS_MULTIDEVICEPARAMETERVALUES = _descriptor.Descriptor(
  name='MultiDeviceParameterValues',
  full_name='motionmaster.MotionMasterMessage.Status.MultiDeviceParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection', full_name='motionmaster.MotionMasterMessage.Status.MultiDeviceParameterValues.collection', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19336,
  serialized_end=19448,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_FILELIST = _descriptor.Descriptor(
  name='FileList',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.FileList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.FileList.files', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19660,
  serialized_end=19685,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19688,
  serialized_end=19838,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST = _descriptor.Descriptor(
  name='DeviceFileList',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_list', full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.file_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_FILELIST, _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='motionmaster.MotionMasterMessage.Status.DeviceFileList.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=19451,
  serialized_end=19846,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20077,
  serialized_end=20230,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20233,
  serialized_end=20406,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE = _descriptor.Descriptor(
  name='DeviceFile',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.success', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.error', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='motionmaster.MotionMasterMessage.Status.DeviceFile.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=19849,
  serialized_end=20414,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_INFO = _descriptor.Descriptor(
  name='Info',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Info.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Info.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20770,
  serialized_end=20807,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Success.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20809,
  serialized_end=20849,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_WARNING = _descriptor.Descriptor(
  name='Warning',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Warning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Warning.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Warning.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20851,
  serialized_end=20891,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Error.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20893,
  serialized_end=20931,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT = _descriptor.Descriptor(
  name='DeviceEvent',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.success', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.warning', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.error', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_INFO, _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_WARNING, _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.DeviceEvent.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=20417,
  serialized_end=20941,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21285,
  serialized_end=21455,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21458,
  serialized_end=21788,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_PROGRESS = _descriptor.Descriptor(
  name='Progress',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Progress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentage', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Progress.percentage', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Progress.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19287,
  serialized_end=19334,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION = _descriptor.Descriptor(
  name='DeviceFirmwareInstallation',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='progress', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.progress', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR, _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_PROGRESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=20944,
  serialized_end=21847,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21982,
  serialized_end=22142,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICELOG = _descriptor.Descriptor(
  name='DeviceLog',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='motionmaster.MotionMasterMessage.Status.DeviceLog.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=21850,
  serialized_end=22150,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22452,
  serialized_end=22599,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING = _descriptor.Descriptor(
  name='Warning',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Warning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Warning.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Warning.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22602,
  serialized_end=22753,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22756,
  serialized_end=22935,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET = _descriptor.Descriptor(
  name='DeviceFaultReset',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.warning', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING, _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.DeviceFaultReset.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=22153,
  serialized_end=22945,
)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23179,
  serialized_end=23345,
)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23348,
  serialized_end=23803,
)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING = _descriptor.Descriptor(
  name='CoggingTorqueRecording',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=22948,
  serialized_end=23813,
)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_TABLE = _descriptor.Descriptor(
  name='Table',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Table',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Table.data', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24027,
  serialized_end=24048,
)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24051,
  serialized_end=24234,
)

_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA = _descriptor.Descriptor(
  name='CoggingTorqueData',
  full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.table', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.error', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_TABLE, _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='motionmaster.MotionMasterMessage.Status.CoggingTorqueData.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=23816,
  serialized_end=24242,
)

_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24455,
  serialized_end=24614,
)

_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24617,
  serialized_end=24823,
)

_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION = _descriptor.Descriptor(
  name='OffsetDetection',
  full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.OffsetDetection.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=24245,
  serialized_end=24833,
)

_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25058,
  serialized_end=25221,
)

_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25224,
  serialized_end=25580,
)

_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION = _descriptor.Descriptor(
  name='PlantIdentification',
  full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.PlantIdentification.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=24836,
  serialized_end=25590,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25818,
  serialized_end=25982,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25985,
  serialized_end=26342,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION = _descriptor.Descriptor(
  name='SystemIdentification',
  full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.SystemIdentification.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=25593,
  serialized_end=26352,
)

_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26630,
  serialized_end=26843,
)

_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING = _descriptor.Descriptor(
  name='Warning',
  full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Warning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Warning.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Warning.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26846,
  serialized_end=27061,
)

_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27064,
  serialized_end=27339,
)

_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING = _descriptor.Descriptor(
  name='AutoTuning',
  full_name='motionmaster.MotionMasterMessage.Status.AutoTuning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.warning', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING, _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.AutoTuning.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=26355,
  serialized_end=27349,
)

_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.MotionController.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.MotionController.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.MotionController.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27697,
  serialized_end=27844,
)

_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.MotionController.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.MotionController.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.MotionController.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27847,
  serialized_end=28169,
)

_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER = _descriptor.Descriptor(
  name='MotionController',
  full_name='motionmaster.MotionMasterMessage.Status.MotionController',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.MotionController.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='controller_type', full_name='motionmaster.MotionMasterMessage.Status.MotionController.controller_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='motionmaster.MotionMasterMessage.Status.MotionController.enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='motionmaster.MotionMasterMessage.Status.MotionController.filter', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.MotionController.success', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.MotionController.error', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR, ],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_CONTROLLERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.MotionController.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=27352,
  serialized_end=28254,
)

_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28552,
  serialized_end=28731,
)

_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING = _descriptor.Descriptor(
  name='Warning',
  full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Warning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Warning.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Warning.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28734,
  serialized_end=28898,
)

_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28901,
  serialized_end=29243,
)

_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR = _descriptor.Descriptor(
  name='SignalGenerator',
  full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.warning', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING, _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.SignalGenerator.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=28257,
  serialized_end=29253,
)

_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29683,
  serialized_end=29839,
)

_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING = _descriptor.Descriptor(
  name='Warning',
  full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Warning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Warning.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Warning.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29842,
  serialized_end=30012,
)

_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30015,
  serialized_end=30202,
)

_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES = _descriptor.Descriptor(
  name='MonitoringParameterValues',
  full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_parameter_values', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.device_parameter_values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.success', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='warning', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.warning', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.error', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING, _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=29256,
  serialized_end=30212,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30410,
  serialized_end=30551,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30554,
  serialized_end=30715,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP = _descriptor.Descriptor(
  name='DeviceStop',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.DeviceStop.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=30215,
  serialized_end=30725,
)

_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31039,
  serialized_end=31190,
)

_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31193,
  serialized_end=31383,
)

_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE = _descriptor.Descriptor(
  name='EthercatNetworkState',
  full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.success', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR, ],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.EthercatNetworkState.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=30728,
  serialized_end=31470,
)

_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31704,
  serialized_end=31870,
)

_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31873,
  serialized_end=32088,
)

_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION = _descriptor.Descriptor(
  name='NarrowAngleCalibration',
  full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=31473,
  serialized_end=32098,
)

_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERMAGNETDISTANCE = _descriptor.Descriptor(
  name='CirculoEncoderMagnetDistance',
  full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderMagnetDistance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderMagnetDistance.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoder_port', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderMagnetDistance.encoder_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distance', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderMagnetDistance.distance', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderMagnetDistance.position', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32100,
  serialized_end=32212,
)

_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32537,
  serialized_end=32726,
)

_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32729,
  serialized_end=32988,
)

_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE = _descriptor.Descriptor(
  name='CirculoEncoderNarrowAngleCalibrationProcedure',
  full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoder_port', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.encoder_port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.success', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=32215,
  serialized_end=32998,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33300,
  serialized_end=33448,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33451,
  serialized_end=33674,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE = _descriptor.Descriptor(
  name='DeviceCiA402State',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.device_address', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.success', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR, ],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.DeviceCiA402State.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=33001,
  serialized_end=33865,
)

_MOTIONMASTERMESSAGE_STATUS_SYSTEMLOG = _descriptor.Descriptor(
  name='SystemLog',
  full_name='motionmaster.MotionMasterMessage.Status.SystemLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='motionmaster.MotionMasterMessage.Status.SystemLog.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_env', full_name='motionmaster.MotionMasterMessage.Status.SystemLog.run_env', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33867,
  serialized_end=33912,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS = _descriptor.Descriptor(
  name='Success',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Success',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Success.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Success.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34129,
  serialized_end=34289,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Error.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34292,
  serialized_end=34520,
)

_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE = _descriptor.Descriptor(
  name='DeviceSiiRestore',
  full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_position', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.device_position', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.success', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS, _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=33915,
  serialized_end=34530,
)

_MOTIONMASTERMESSAGE_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='motionmaster.MotionMasterMessage.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='system_pong', full_name='motionmaster.MotionMasterMessage.Status.system_pong', index=0,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_version', full_name='motionmaster.MotionMasterMessage.Status.system_version', index=1,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_event', full_name='motionmaster.MotionMasterMessage.Status.system_event', index=2,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_info', full_name='motionmaster.MotionMasterMessage.Status.device_info', index=3,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_parameter_info', full_name='motionmaster.MotionMasterMessage.Status.device_parameter_info', index=4,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_parameter_values', full_name='motionmaster.MotionMasterMessage.Status.device_parameter_values', index=5,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multi_device_parameter_values', full_name='motionmaster.MotionMasterMessage.Status.multi_device_parameter_values', index=6,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_file_list', full_name='motionmaster.MotionMasterMessage.Status.device_file_list', index=7,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_file', full_name='motionmaster.MotionMasterMessage.Status.device_file', index=8,
      number=109, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_event', full_name='motionmaster.MotionMasterMessage.Status.device_event', index=9,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_firmware_installation', full_name='motionmaster.MotionMasterMessage.Status.device_firmware_installation', index=10,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_log', full_name='motionmaster.MotionMasterMessage.Status.device_log', index=11,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_fault_reset', full_name='motionmaster.MotionMasterMessage.Status.device_fault_reset', index=12,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cogging_torque_recording', full_name='motionmaster.MotionMasterMessage.Status.cogging_torque_recording', index=13,
      number=114, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cogging_torque_data', full_name='motionmaster.MotionMasterMessage.Status.cogging_torque_data', index=14,
      number=115, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_detection', full_name='motionmaster.MotionMasterMessage.Status.offset_detection', index=15,
      number=116, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plant_identification', full_name='motionmaster.MotionMasterMessage.Status.plant_identification', index=16,
      number=117, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_tuning', full_name='motionmaster.MotionMasterMessage.Status.auto_tuning', index=17,
      number=118, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='motion_controller', full_name='motionmaster.MotionMasterMessage.Status.motion_controller', index=18,
      number=119, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signal_generator', full_name='motionmaster.MotionMasterMessage.Status.signal_generator', index=19,
      number=120, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='monitoring_parameter_values', full_name='motionmaster.MotionMasterMessage.Status.monitoring_parameter_values', index=20,
      number=121, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_stop', full_name='motionmaster.MotionMasterMessage.Status.device_stop', index=21,
      number=122, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ethercat_network_state', full_name='motionmaster.MotionMasterMessage.Status.ethercat_network_state', index=22,
      number=123, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='narrow_angle_calibration', full_name='motionmaster.MotionMasterMessage.Status.narrow_angle_calibration', index=23,
      number=124, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_identification', full_name='motionmaster.MotionMasterMessage.Status.system_identification', index=24,
      number=125, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='circulo_encoder_magnet_distance', full_name='motionmaster.MotionMasterMessage.Status.circulo_encoder_magnet_distance', index=25,
      number=126, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='circulo_encoder_narrow_angle_calibration_procedure', full_name='motionmaster.MotionMasterMessage.Status.circulo_encoder_narrow_angle_calibration_procedure', index=26,
      number=127, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_cia402_state', full_name='motionmaster.MotionMasterMessage.Status.device_cia402_state', index=27,
      number=128, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_log', full_name='motionmaster.MotionMasterMessage.Status.system_log', index=28,
      number=129, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_sii_restore', full_name='motionmaster.MotionMasterMessage.Status.device_sii_restore', index=29,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_STATUS_SYSTEMPONG, _MOTIONMASTERMESSAGE_STATUS_SYSTEMVERSION, _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT, _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO, _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO, _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_STATUS_MULTIDEVICEPARAMETERVALUES, _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST, _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE, _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT, _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION, _MOTIONMASTERMESSAGE_STATUS_DEVICELOG, _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET, _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING, _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA, _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION, _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION, _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION, _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING, _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER, _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR, _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES, _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP, _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE, _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION, _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERMAGNETDISTANCE, _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE, _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE, _MOTIONMASTERMESSAGE_STATUS_SYSTEMLOG, _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='motionmaster.MotionMasterMessage.Status.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=13194,
  serialized_end=34552,
)

_MOTIONMASTERMESSAGE = _descriptor.Descriptor(
  name='MotionMasterMessage',
  full_name='motionmaster.MotionMasterMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='motionmaster.MotionMasterMessage.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='motionmaster.MotionMasterMessage.request', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='motionmaster.MotionMasterMessage.status', index=2,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_MOTIONMASTERMESSAGE_REQUEST, _MOTIONMASTERMESSAGE_STATUS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='motionmaster.MotionMasterMessage.type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=39,
  serialized_end=34573,
)

_MOTIONMASTERMESSAGE_REQUEST_PINGSYSTEM.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMVERSION.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEINFO.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERINFO.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES_PARAMETER.containing_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES.fields_by_name['parameters'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES_PARAMETER
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETMULTIDEVICEPARAMETERVALUES.fields_by_name['collection'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST_GETMULTIDEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['int_value'])
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['int_value'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['uint_value'])
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['uint_value'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['float_value'])
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['float_value'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['string_value'])
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['string_value'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['raw_value'])
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['raw_value'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES.fields_by_name['parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETMULTIDEVICEPARAMETERVALUES.fields_by_name['collection'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST_SETMULTIDEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILELIST.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICEFILE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_DELETEDEVICEFILE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_RESETDEVICEFAULT.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STOPDEVICE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTDEVICEFIRMWAREINSTALLATION.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICELOG.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTCOGGINGTORQUERECORDING.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETCOGGINGTORQUEDATA.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTOFFSETDETECTION.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTPLANTIDENTIFICATION.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTSYSTEMIDENTIFICATION.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS.fields_by_name['controller_type'].enum_type = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS_CONTROLLERTYPE
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS.containing_type = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS_CONTROLLERTYPE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_VELOCITYPARAMETERS.containing_type = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.fields_by_name['position_parameters'].message_type = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.fields_by_name['velocity_parameters'].message_type = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_VELOCITYPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.fields_by_name['position_parameters'])
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.fields_by_name['position_parameters'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.fields_by_name['velocity_parameters'])
_MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.fields_by_name['velocity_parameters'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST_SETMOTIONCONTROLLERPARAMETERS.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER.fields_by_name['controller_type'].enum_type = _MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER_CONTROLLERTYPE
_MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER_CONTROLLERTYPE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER
_MOTIONMASTERMESSAGE_REQUEST_DISABLEMOTIONCONTROLLER.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSTEPRESPONSE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONADVANCEDSTEPRESPONSE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONRAMP.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONTRAPEZOIDAL.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONBIDIRECTIONAL.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSINEWAVE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSTEPRESPONSE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYADVANCEDSTEPRESPONSE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYRAMP.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYTRAPEZOIDAL.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYBIDIRECTIONAL.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSINEWAVE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESTEPRESPONSE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEADVANCEDSTEPRESPONSE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUERAMP.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUETRAPEZOIDAL.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEBIDIRECTIONAL.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESINEWAVE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_step_response'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSTEPRESPONSE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_advanced_step_response'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONADVANCEDSTEPRESPONSE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_ramp'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONRAMP
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_trapezoidal'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONTRAPEZOIDAL
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_bidirectional'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONBIDIRECTIONAL
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_sine_wave'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSINEWAVE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_step_response'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSTEPRESPONSE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_advanced_step_response'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYADVANCEDSTEPRESPONSE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_ramp'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYRAMP
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_trapezoidal'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYTRAPEZOIDAL
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_bidirectional'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYBIDIRECTIONAL
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_sine_wave'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSINEWAVE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_step_response'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESTEPRESPONSE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_advanced_step_response'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEADVANCEDSTEPRESPONSE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_ramp'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUERAMP
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_trapezoidal'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUETRAPEZOIDAL
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_bidirectional'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEBIDIRECTIONAL
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_sine_wave'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESINEWAVE
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_step_response'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_step_response'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_advanced_step_response'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_advanced_step_response'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_ramp'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_ramp'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_trapezoidal'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_trapezoidal'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_bidirectional'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_bidirectional'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_sine_wave'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['position_sine_wave'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_step_response'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_step_response'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_advanced_step_response'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_advanced_step_response'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_ramp'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_ramp'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_trapezoidal'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_trapezoidal'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_bidirectional'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_bidirectional'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_sine_wave'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['velocity_sine_wave'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_step_response'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_step_response'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_advanced_step_response'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_advanced_step_response'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_ramp'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_ramp'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_trapezoidal'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_trapezoidal'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_bidirectional'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_bidirectional'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_sine_wave'])
_MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.fields_by_name['torque_sine_wave'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS.oneofs_by_name['signal']
_MOTIONMASTERMESSAGE_REQUEST_STARTSIGNALGENERATOR.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STOPSIGNALGENERATOR.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTMONITORINGDEVICEPARAMETERVALUES.fields_by_name['get_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST_STARTMONITORINGDEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STOPMONITORINGDEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETETHERCATNETWORKSTATE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE.fields_by_name['state'].enum_type = _MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE_STATE
_MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE_STATE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE
_MOTIONMASTERMESSAGE_REQUEST_STARTNARROWANGLECALIBRATION.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETSYSTEMCLIENTTIMEOUT.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETCIRCULOENCODERMAGNETDISTANCE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTCIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_GETDEVICECIA402STATE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE.fields_by_name['state'].enum_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE_STATE
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE_STATE.containing_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE
_MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMLOG.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST_STARTDEVICESIIRESTORE.containing_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['ping_system'].message_type = _MOTIONMASTERMESSAGE_REQUEST_PINGSYSTEM
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_system_version'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMVERSION
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_info'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEINFO
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_parameter_info'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERINFO
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_multi_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETMULTIDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_multi_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETMULTIDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_file_list'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILELIST
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_file'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_file'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEFILE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['delete_device_file'].message_type = _MOTIONMASTERMESSAGE_REQUEST_DELETEDEVICEFILE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['reset_device_fault'].message_type = _MOTIONMASTERMESSAGE_REQUEST_RESETDEVICEFAULT
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_device'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STOPDEVICE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_device_firmware_installation'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTDEVICEFIRMWAREINSTALLATION
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_log'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICELOG
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_cogging_torque_recording'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTCOGGINGTORQUERECORDING
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_cogging_torque_data'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETCOGGINGTORQUEDATA
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_offset_detection'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTOFFSETDETECTION
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_plant_identification'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTPLANTIDENTIFICATION
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['compute_auto_tuning_gains'].message_type = _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_motion_controller_parameters'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETMOTIONCONTROLLERPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['enable_motion_controller'].message_type = _MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['disable_motion_controller'].message_type = _MOTIONMASTERMESSAGE_REQUEST_DISABLEMOTIONCONTROLLER
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_signal_generator_parameters'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_signal_generator'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTSIGNALGENERATOR
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_signal_generator'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STOPSIGNALGENERATOR
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_monitoring_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTMONITORINGDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_monitoring_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STOPMONITORINGDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_ethercat_network_state'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETETHERCATNETWORKSTATE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_ethercat_network_state'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_narrow_angle_calibration'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTNARROWANGLECALIBRATION
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_system_client_timeout'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETSYSTEMCLIENTTIMEOUT
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_system_identification'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTSYSTEMIDENTIFICATION
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_circulo_encoder_magnet_distance'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETCIRCULOENCODERMAGNETDISTANCE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_circulo_encoder_narrow_angle_calibration_procedure'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTCIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_cia402_state'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETDEVICECIA402STATE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_cia402_state'].message_type = _MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_system_log'].message_type = _MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMLOG
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_device_sii_restore'].message_type = _MOTIONMASTERMESSAGE_REQUEST_STARTDEVICESIIRESTORE
_MOTIONMASTERMESSAGE_REQUEST.containing_type = _MOTIONMASTERMESSAGE
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['ping_system'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['ping_system'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_system_version'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_system_version'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_info'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_info'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_parameter_info'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_parameter_info'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_parameter_values'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_multi_device_parameter_values'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_multi_device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_parameter_values'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_multi_device_parameter_values'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_multi_device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_file_list'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_file_list'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_file'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_file'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_file'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_file'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['delete_device_file'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['delete_device_file'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['reset_device_fault'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['reset_device_fault'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_device'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_device'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_device_firmware_installation'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_device_firmware_installation'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_log'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_log'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_cogging_torque_recording'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_cogging_torque_recording'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_cogging_torque_data'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_cogging_torque_data'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_offset_detection'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_offset_detection'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_plant_identification'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_plant_identification'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['compute_auto_tuning_gains'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['compute_auto_tuning_gains'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_motion_controller_parameters'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_motion_controller_parameters'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['enable_motion_controller'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['enable_motion_controller'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['disable_motion_controller'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['disable_motion_controller'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_signal_generator_parameters'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_signal_generator_parameters'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_signal_generator'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_signal_generator'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_signal_generator'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_signal_generator'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_monitoring_device_parameter_values'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_monitoring_device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_monitoring_device_parameter_values'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['stop_monitoring_device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_ethercat_network_state'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_ethercat_network_state'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_ethercat_network_state'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_ethercat_network_state'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_narrow_angle_calibration'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_narrow_angle_calibration'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_system_client_timeout'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_system_client_timeout'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_system_identification'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_system_identification'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_circulo_encoder_magnet_distance'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_circulo_encoder_magnet_distance'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_circulo_encoder_narrow_angle_calibration_procedure'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_circulo_encoder_narrow_angle_calibration_procedure'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_cia402_state'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_device_cia402_state'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_cia402_state'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['set_device_cia402_state'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_system_log'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['get_system_log'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_device_sii_restore'])
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_device_sii_restore'].containing_oneof = _MOTIONMASTERMESSAGE_REQUEST.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMPONG.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMVERSION.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO_CODE
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING_CODE
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['info'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['warning'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['state'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_STATE
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_STATE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['info'])
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['info'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['warning'])
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['warning'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['state'])
_MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.fields_by_name['state'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE.fields_by_name['type'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE_TYPE
_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO
_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE_TYPE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE
_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO.fields_by_name['devices'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE
_MOTIONMASTERMESSAGE_STATUS_DEVICEINFO.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER.fields_by_name['value_type'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER_VALUETYPE
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER_VALUETYPE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO.fields_by_name['parameters'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['int_value'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['int_value'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['uint_value'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['uint_value'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['float_value'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['float_value'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['string_value'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['string_value'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['raw_value'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['raw_value'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['type_value']
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PROGRESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES.fields_by_name['parameter_values'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES.fields_by_name['progress'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PROGRESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_MULTIDEVICEPARAMETERVALUES.fields_by_name['collection'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS_MULTIDEVICEPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_FILELIST.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.fields_by_name['file_list'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_FILELIST
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.fields_by_name['file_list'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.fields_by_name['file_list'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['content'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['content'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_INFO.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_WARNING.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['info'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_INFO
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['warning'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_WARNING
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['info'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['info'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['warning'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['warning'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_PROGRESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['progress'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_PROGRESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['progress'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.fields_by_name['progress'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICELOG
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICELOG.fields_by_name['content'])
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG.fields_by_name['content'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICELOG.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICELOG.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICELOG.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICELOG.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['warning'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['warning'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['warning'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_TABLE.containing_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.fields_by_name['table'].message_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_TABLE
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.fields_by_name['table'])
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.fields_by_name['table'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.oneofs_by_name['data'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA.oneofs_by_name['data']
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING_CODE
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING.containing_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['warning'].message_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['warning'])
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['warning'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.fields_by_name['controller_type'].enum_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_CONTROLLERTYPE
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_CONTROLLERTYPE.containing_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING_CODE
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING.containing_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['warning'].message_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['warning'])
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['warning'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING_CODE
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING.containing_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['warning'].message_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['warning'])
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['warning'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['state'].enum_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_STATE
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_STATE.containing_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['state'])
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['state'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERMAGNETDISTANCE.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['state'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_STATE
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_STATE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['state'])
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['state'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_SYSTEMLOG.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR.fields_by_name['code'].enum_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR_CODE
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR_CODE.containing_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.fields_by_name['success'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.fields_by_name['error'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.containing_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.fields_by_name['success'])
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.fields_by_name['success'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.oneofs_by_name['status'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.fields_by_name['error'])
_MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.fields_by_name['error'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE.oneofs_by_name['status']
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_pong'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMPONG
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_version'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMVERSION
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_event'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_info'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_parameter_info'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['multi_device_parameter_values'].message_type = _MOTIONMASTERMESSAGE_STATUS_MULTIDEVICEPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_file_list'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_file'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_event'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_firmware_installation'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_log'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICELOG
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_fault_reset'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['cogging_torque_recording'].message_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['cogging_torque_data'].message_type = _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['offset_detection'].message_type = _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['plant_identification'].message_type = _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['auto_tuning'].message_type = _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['motion_controller'].message_type = _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['signal_generator'].message_type = _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['monitoring_parameter_values'].message_type = _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_stop'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['ethercat_network_state'].message_type = _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['narrow_angle_calibration'].message_type = _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_identification'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['circulo_encoder_magnet_distance'].message_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERMAGNETDISTANCE
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['circulo_encoder_narrow_angle_calibration_procedure'].message_type = _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_cia402_state'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_log'].message_type = _MOTIONMASTERMESSAGE_STATUS_SYSTEMLOG
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_sii_restore'].message_type = _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE
_MOTIONMASTERMESSAGE_STATUS.containing_type = _MOTIONMASTERMESSAGE
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_pong'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_pong'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_version'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_version'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_event'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_event'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_info'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_info'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_parameter_info'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_parameter_info'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_parameter_values'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['multi_device_parameter_values'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['multi_device_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_file_list'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_file_list'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_file'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_file'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_event'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_event'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_firmware_installation'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_firmware_installation'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_log'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_log'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_fault_reset'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_fault_reset'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['cogging_torque_recording'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['cogging_torque_recording'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['cogging_torque_data'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['cogging_torque_data'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['offset_detection'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['offset_detection'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['plant_identification'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['plant_identification'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['auto_tuning'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['auto_tuning'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['motion_controller'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['motion_controller'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['signal_generator'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['signal_generator'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['monitoring_parameter_values'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['monitoring_parameter_values'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_stop'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_stop'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['ethercat_network_state'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['ethercat_network_state'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['narrow_angle_calibration'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['narrow_angle_calibration'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_identification'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_identification'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['circulo_encoder_magnet_distance'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['circulo_encoder_magnet_distance'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['circulo_encoder_narrow_angle_calibration_procedure'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['circulo_encoder_narrow_angle_calibration_procedure'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_cia402_state'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_cia402_state'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_log'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['system_log'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_sii_restore'])
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['device_sii_restore'].containing_oneof = _MOTIONMASTERMESSAGE_STATUS.oneofs_by_name['type']
_MOTIONMASTERMESSAGE.fields_by_name['request'].message_type = _MOTIONMASTERMESSAGE_REQUEST
_MOTIONMASTERMESSAGE.fields_by_name['status'].message_type = _MOTIONMASTERMESSAGE_STATUS
_MOTIONMASTERMESSAGE.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE.fields_by_name['request'])
_MOTIONMASTERMESSAGE.fields_by_name['request'].containing_oneof = _MOTIONMASTERMESSAGE.oneofs_by_name['type']
_MOTIONMASTERMESSAGE.oneofs_by_name['type'].fields.append(
  _MOTIONMASTERMESSAGE.fields_by_name['status'])
_MOTIONMASTERMESSAGE.fields_by_name['status'].containing_oneof = _MOTIONMASTERMESSAGE.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['MotionMasterMessage'] = _MOTIONMASTERMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MotionMasterMessage = _reflection.GeneratedProtocolMessageType('MotionMasterMessage', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'PingSystem' : _reflection.GeneratedProtocolMessageType('PingSystem', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_PINGSYSTEM,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.PingSystem)
      })
    ,

    'GetSystemVersion' : _reflection.GeneratedProtocolMessageType('GetSystemVersion', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMVERSION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetSystemVersion)
      })
    ,

    'GetDeviceInfo' : _reflection.GeneratedProtocolMessageType('GetDeviceInfo', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEINFO,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceInfo)
      })
    ,

    'GetDeviceParameterInfo' : _reflection.GeneratedProtocolMessageType('GetDeviceParameterInfo', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERINFO,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceParameterInfo)
      })
    ,

    'GetDeviceParameterValues' : _reflection.GeneratedProtocolMessageType('GetDeviceParameterValues', (_message.Message,), {

      'Parameter' : _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES_PARAMETER,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues.Parameter)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceParameterValues)
      })
    ,

    'GetMultiDeviceParameterValues' : _reflection.GeneratedProtocolMessageType('GetMultiDeviceParameterValues', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETMULTIDEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetMultiDeviceParameterValues)
      })
    ,

    'SetDeviceParameterValues' : _reflection.GeneratedProtocolMessageType('SetDeviceParameterValues', (_message.Message,), {

      'ParameterValue' : _reflection.GeneratedProtocolMessageType('ParameterValue', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES_PARAMETERVALUE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetDeviceParameterValues)
      })
    ,

    'SetMultiDeviceParameterValues' : _reflection.GeneratedProtocolMessageType('SetMultiDeviceParameterValues', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETMULTIDEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetMultiDeviceParameterValues)
      })
    ,

    'GetDeviceFileList' : _reflection.GeneratedProtocolMessageType('GetDeviceFileList', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILELIST,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceFileList)
      })
    ,

    'GetDeviceFile' : _reflection.GeneratedProtocolMessageType('GetDeviceFile', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICEFILE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceFile)
      })
    ,

    'SetDeviceFile' : _reflection.GeneratedProtocolMessageType('SetDeviceFile', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETDEVICEFILE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetDeviceFile)
      })
    ,

    'DeleteDeviceFile' : _reflection.GeneratedProtocolMessageType('DeleteDeviceFile', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_DELETEDEVICEFILE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.DeleteDeviceFile)
      })
    ,

    'ResetDeviceFault' : _reflection.GeneratedProtocolMessageType('ResetDeviceFault', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_RESETDEVICEFAULT,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.ResetDeviceFault)
      })
    ,

    'StopDevice' : _reflection.GeneratedProtocolMessageType('StopDevice', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STOPDEVICE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StopDevice)
      })
    ,

    'StartDeviceFirmwareInstallation' : _reflection.GeneratedProtocolMessageType('StartDeviceFirmwareInstallation', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTDEVICEFIRMWAREINSTALLATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartDeviceFirmwareInstallation)
      })
    ,

    'GetDeviceLog' : _reflection.GeneratedProtocolMessageType('GetDeviceLog', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICELOG,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceLog)
      })
    ,

    'StartCoggingTorqueRecording' : _reflection.GeneratedProtocolMessageType('StartCoggingTorqueRecording', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTCOGGINGTORQUERECORDING,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartCoggingTorqueRecording)
      })
    ,

    'GetCoggingTorqueData' : _reflection.GeneratedProtocolMessageType('GetCoggingTorqueData', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETCOGGINGTORQUEDATA,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetCoggingTorqueData)
      })
    ,

    'StartOffsetDetection' : _reflection.GeneratedProtocolMessageType('StartOffsetDetection', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTOFFSETDETECTION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartOffsetDetection)
      })
    ,

    'StartPlantIdentification' : _reflection.GeneratedProtocolMessageType('StartPlantIdentification', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTPLANTIDENTIFICATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartPlantIdentification)
      })
    ,

    'StartSystemIdentification' : _reflection.GeneratedProtocolMessageType('StartSystemIdentification', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTSYSTEMIDENTIFICATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartSystemIdentification)
      })
    ,

    'ComputeAutoTuningGains' : _reflection.GeneratedProtocolMessageType('ComputeAutoTuningGains', (_message.Message,), {

      'PositionParameters' : _reflection.GeneratedProtocolMessageType('PositionParameters', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_POSITIONPARAMETERS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters)
        })
      ,

      'VelocityParameters' : _reflection.GeneratedProtocolMessageType('VelocityParameters', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS_VELOCITYPARAMETERS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains.VelocityParameters)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_COMPUTEAUTOTUNINGGAINS,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.ComputeAutoTuningGains)
      })
    ,

    'SetMotionControllerParameters' : _reflection.GeneratedProtocolMessageType('SetMotionControllerParameters', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETMOTIONCONTROLLERPARAMETERS,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetMotionControllerParameters)
      })
    ,

    'EnableMotionController' : _reflection.GeneratedProtocolMessageType('EnableMotionController', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_ENABLEMOTIONCONTROLLER,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.EnableMotionController)
      })
    ,

    'DisableMotionController' : _reflection.GeneratedProtocolMessageType('DisableMotionController', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_DISABLEMOTIONCONTROLLER,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.DisableMotionController)
      })
    ,

    'SetSignalGeneratorParameters' : _reflection.GeneratedProtocolMessageType('SetSignalGeneratorParameters', (_message.Message,), {

      'PositionStepResponse' : _reflection.GeneratedProtocolMessageType('PositionStepResponse', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSTEPRESPONSE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionStepResponse)
        })
      ,

      'PositionAdvancedStepResponse' : _reflection.GeneratedProtocolMessageType('PositionAdvancedStepResponse', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONADVANCEDSTEPRESPONSE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponse)
        })
      ,

      'PositionRamp' : _reflection.GeneratedProtocolMessageType('PositionRamp', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONRAMP,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp)
        })
      ,

      'PositionTrapezoidal' : _reflection.GeneratedProtocolMessageType('PositionTrapezoidal', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONTRAPEZOIDAL,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal)
        })
      ,

      'PositionBidirectional' : _reflection.GeneratedProtocolMessageType('PositionBidirectional', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONBIDIRECTIONAL,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional)
        })
      ,

      'PositionSineWave' : _reflection.GeneratedProtocolMessageType('PositionSineWave', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_POSITIONSINEWAVE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWave)
        })
      ,

      'VelocityStepResponse' : _reflection.GeneratedProtocolMessageType('VelocityStepResponse', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSTEPRESPONSE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityStepResponse)
        })
      ,

      'VelocityAdvancedStepResponse' : _reflection.GeneratedProtocolMessageType('VelocityAdvancedStepResponse', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYADVANCEDSTEPRESPONSE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityAdvancedStepResponse)
        })
      ,

      'VelocityRamp' : _reflection.GeneratedProtocolMessageType('VelocityRamp', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYRAMP,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp)
        })
      ,

      'VelocityTrapezoidal' : _reflection.GeneratedProtocolMessageType('VelocityTrapezoidal', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYTRAPEZOIDAL,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal)
        })
      ,

      'VelocityBidirectional' : _reflection.GeneratedProtocolMessageType('VelocityBidirectional', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYBIDIRECTIONAL,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional)
        })
      ,

      'VelocitySineWave' : _reflection.GeneratedProtocolMessageType('VelocitySineWave', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_VELOCITYSINEWAVE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocitySineWave)
        })
      ,

      'TorqueStepResponse' : _reflection.GeneratedProtocolMessageType('TorqueStepResponse', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESTEPRESPONSE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueStepResponse)
        })
      ,

      'TorqueAdvancedStepResponse' : _reflection.GeneratedProtocolMessageType('TorqueAdvancedStepResponse', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEADVANCEDSTEPRESPONSE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueAdvancedStepResponse)
        })
      ,

      'TorqueRamp' : _reflection.GeneratedProtocolMessageType('TorqueRamp', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUERAMP,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRamp)
        })
      ,

      'TorqueTrapezoidal' : _reflection.GeneratedProtocolMessageType('TorqueTrapezoidal', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUETRAPEZOIDAL,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal)
        })
      ,

      'TorqueBidirectional' : _reflection.GeneratedProtocolMessageType('TorqueBidirectional', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUEBIDIRECTIONAL,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional)
        })
      ,

      'TorqueSineWave' : _reflection.GeneratedProtocolMessageType('TorqueSineWave', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS_TORQUESINEWAVE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueSineWave)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSIGNALGENERATORPARAMETERS,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSignalGeneratorParameters)
      })
    ,

    'StartSignalGenerator' : _reflection.GeneratedProtocolMessageType('StartSignalGenerator', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTSIGNALGENERATOR,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartSignalGenerator)
      })
    ,

    'StopSignalGenerator' : _reflection.GeneratedProtocolMessageType('StopSignalGenerator', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STOPSIGNALGENERATOR,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StopSignalGenerator)
      })
    ,

    'StartMonitoringDeviceParameterValues' : _reflection.GeneratedProtocolMessageType('StartMonitoringDeviceParameterValues', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTMONITORINGDEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartMonitoringDeviceParameterValues)
      })
    ,

    'StopMonitoringDeviceParameterValues' : _reflection.GeneratedProtocolMessageType('StopMonitoringDeviceParameterValues', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STOPMONITORINGDEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StopMonitoringDeviceParameterValues)
      })
    ,

    'GetEthercatNetworkState' : _reflection.GeneratedProtocolMessageType('GetEthercatNetworkState', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETETHERCATNETWORKSTATE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetEthercatNetworkState)
      })
    ,

    'SetEthercatNetworkState' : _reflection.GeneratedProtocolMessageType('SetEthercatNetworkState', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETETHERCATNETWORKSTATE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetEthercatNetworkState)
      })
    ,

    'StartNarrowAngleCalibration' : _reflection.GeneratedProtocolMessageType('StartNarrowAngleCalibration', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTNARROWANGLECALIBRATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartNarrowAngleCalibration)
      })
    ,

    'SetSystemClientTimeout' : _reflection.GeneratedProtocolMessageType('SetSystemClientTimeout', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETSYSTEMCLIENTTIMEOUT,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetSystemClientTimeout)
      })
    ,

    'GetCirculoEncoderMagnetDistance' : _reflection.GeneratedProtocolMessageType('GetCirculoEncoderMagnetDistance', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETCIRCULOENCODERMAGNETDISTANCE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetCirculoEncoderMagnetDistance)
      })
    ,

    'StartCirculoEncoderNarrowAngleCalibrationProcedure' : _reflection.GeneratedProtocolMessageType('StartCirculoEncoderNarrowAngleCalibrationProcedure', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTCIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartCirculoEncoderNarrowAngleCalibrationProcedure)
      })
    ,

    'GetDeviceCiA402State' : _reflection.GeneratedProtocolMessageType('GetDeviceCiA402State', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETDEVICECIA402STATE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetDeviceCiA402State)
      })
    ,

    'SetDeviceCiA402State' : _reflection.GeneratedProtocolMessageType('SetDeviceCiA402State', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_SETDEVICECIA402STATE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.SetDeviceCiA402State)
      })
    ,

    'GetSystemLog' : _reflection.GeneratedProtocolMessageType('GetSystemLog', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_GETSYSTEMLOG,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.GetSystemLog)
      })
    ,

    'StartDeviceSiiRestore' : _reflection.GeneratedProtocolMessageType('StartDeviceSiiRestore', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST_STARTDEVICESIIRESTORE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request.StartDeviceSiiRestore)
      })
    ,
    'DESCRIPTOR' : _MOTIONMASTERMESSAGE_REQUEST,
    '__module__' : 'motion_master_pb2'
    # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Request)
    })
  ,

  'Status' : _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {

    'SystemPong' : _reflection.GeneratedProtocolMessageType('SystemPong', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMPONG,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemPong)
      })
    ,

    'SystemVersion' : _reflection.GeneratedProtocolMessageType('SystemVersion', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMVERSION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemVersion)
      })
    ,

    'SystemEvent' : _reflection.GeneratedProtocolMessageType('SystemEvent', (_message.Message,), {

      'Info' : _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_INFO,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemEvent.Info)
        })
      ,

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemEvent.Success)
        })
      ,

      'Warning' : _reflection.GeneratedProtocolMessageType('Warning', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_WARNING,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemEvent.Warning)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemEvent.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMEVENT,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemEvent)
      })
    ,

    'DeviceInfo' : _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), {

      'Device' : _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO_DEVICE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceInfo.Device)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEINFO,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceInfo)
      })
    ,

    'DeviceParameterInfo' : _reflection.GeneratedProtocolMessageType('DeviceParameterInfo', (_message.Message,), {

      'Parameter' : _reflection.GeneratedProtocolMessageType('Parameter', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO_PARAMETER,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceParameterInfo.Parameter)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERINFO,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceParameterInfo)
      })
    ,

    'DeviceParameterValues' : _reflection.GeneratedProtocolMessageType('DeviceParameterValues', (_message.Message,), {

      'ParameterValue' : _reflection.GeneratedProtocolMessageType('ParameterValue', (_message.Message,), {

        'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
          'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_SUCCESS,
          '__module__' : 'motion_master_pb2'
          # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Success)
          })
        ,

        'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
          'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE_ERROR,
          '__module__' : 'motion_master_pb2'
          # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Error)
          })
        ,
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PARAMETERVALUE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceParameterValues.ParameterValue)
        })
      ,

      'Progress' : _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES_PROGRESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceParameterValues.Progress)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceParameterValues)
      })
    ,

    'MultiDeviceParameterValues' : _reflection.GeneratedProtocolMessageType('MultiDeviceParameterValues', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MULTIDEVICEPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MultiDeviceParameterValues)
      })
    ,

    'DeviceFileList' : _reflection.GeneratedProtocolMessageType('DeviceFileList', (_message.Message,), {

      'FileList' : _reflection.GeneratedProtocolMessageType('FileList', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_FILELIST,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFileList.FileList)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFileList.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFILELIST,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFileList)
      })
    ,

    'DeviceFile' : _reflection.GeneratedProtocolMessageType('DeviceFile', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFile.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFile.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFILE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFile)
      })
    ,

    'DeviceEvent' : _reflection.GeneratedProtocolMessageType('DeviceEvent', (_message.Message,), {

      'Info' : _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_INFO,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceEvent.Info)
        })
      ,

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceEvent.Success)
        })
      ,

      'Warning' : _reflection.GeneratedProtocolMessageType('Warning', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_WARNING,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceEvent.Warning)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceEvent.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEEVENT,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceEvent)
      })
    ,

    'DeviceFirmwareInstallation' : _reflection.GeneratedProtocolMessageType('DeviceFirmwareInstallation', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Error)
        })
      ,

      'Progress' : _reflection.GeneratedProtocolMessageType('Progress', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION_PROGRESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation.Progress)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFIRMWAREINSTALLATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFirmwareInstallation)
      })
    ,

    'DeviceLog' : _reflection.GeneratedProtocolMessageType('DeviceLog', (_message.Message,), {

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICELOG_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceLog.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICELOG,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceLog)
      })
    ,

    'DeviceFaultReset' : _reflection.GeneratedProtocolMessageType('DeviceFaultReset', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Success)
        })
      ,

      'Warning' : _reflection.GeneratedProtocolMessageType('Warning', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_WARNING,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Warning)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFaultReset.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICEFAULTRESET,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceFaultReset)
      })
    ,

    'CoggingTorqueRecording' : _reflection.GeneratedProtocolMessageType('CoggingTorqueRecording', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUERECORDING,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CoggingTorqueRecording)
      })
    ,

    'CoggingTorqueData' : _reflection.GeneratedProtocolMessageType('CoggingTorqueData', (_message.Message,), {

      'Table' : _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_TABLE,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Table)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CoggingTorqueData.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_COGGINGTORQUEDATA,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CoggingTorqueData)
      })
    ,

    'OffsetDetection' : _reflection.GeneratedProtocolMessageType('OffsetDetection', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.OffsetDetection.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.OffsetDetection.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_OFFSETDETECTION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.OffsetDetection)
      })
    ,

    'PlantIdentification' : _reflection.GeneratedProtocolMessageType('PlantIdentification', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.PlantIdentification.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.PlantIdentification.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_PLANTIDENTIFICATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.PlantIdentification)
      })
    ,

    'SystemIdentification' : _reflection.GeneratedProtocolMessageType('SystemIdentification', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemIdentification.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemIdentification.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMIDENTIFICATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemIdentification)
      })
    ,

    'AutoTuning' : _reflection.GeneratedProtocolMessageType('AutoTuning', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.AutoTuning.Success)
        })
      ,

      'Warning' : _reflection.GeneratedProtocolMessageType('Warning', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_WARNING,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.AutoTuning.Warning)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.AutoTuning.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_AUTOTUNING,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.AutoTuning)
      })
    ,

    'MotionController' : _reflection.GeneratedProtocolMessageType('MotionController', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MotionController.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MotionController.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MOTIONCONTROLLER,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MotionController)
      })
    ,

    'SignalGenerator' : _reflection.GeneratedProtocolMessageType('SignalGenerator', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SignalGenerator.Success)
        })
      ,

      'Warning' : _reflection.GeneratedProtocolMessageType('Warning', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_WARNING,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SignalGenerator.Warning)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SignalGenerator.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SIGNALGENERATOR,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SignalGenerator)
      })
    ,

    'MonitoringParameterValues' : _reflection.GeneratedProtocolMessageType('MonitoringParameterValues', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Success)
        })
      ,

      'Warning' : _reflection.GeneratedProtocolMessageType('Warning', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_WARNING,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Warning)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MonitoringParameterValues.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_MONITORINGPARAMETERVALUES,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.MonitoringParameterValues)
      })
    ,

    'DeviceStop' : _reflection.GeneratedProtocolMessageType('DeviceStop', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceStop.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceStop.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICESTOP,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceStop)
      })
    ,

    'EthercatNetworkState' : _reflection.GeneratedProtocolMessageType('EthercatNetworkState', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.EthercatNetworkState.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_ETHERCATNETWORKSTATE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.EthercatNetworkState)
      })
    ,

    'NarrowAngleCalibration' : _reflection.GeneratedProtocolMessageType('NarrowAngleCalibration', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_NARROWANGLECALIBRATION,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.NarrowAngleCalibration)
      })
    ,

    'CirculoEncoderMagnetDistance' : _reflection.GeneratedProtocolMessageType('CirculoEncoderMagnetDistance', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERMAGNETDISTANCE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CirculoEncoderMagnetDistance)
      })
    ,

    'CirculoEncoderNarrowAngleCalibrationProcedure' : _reflection.GeneratedProtocolMessageType('CirculoEncoderNarrowAngleCalibrationProcedure', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_CIRCULOENCODERNARROWANGLECALIBRATIONPROCEDURE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure)
      })
    ,

    'DeviceCiA402State' : _reflection.GeneratedProtocolMessageType('DeviceCiA402State', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceCiA402State.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICECIA402STATE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceCiA402State)
      })
    ,

    'SystemLog' : _reflection.GeneratedProtocolMessageType('SystemLog', (_message.Message,), {
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_SYSTEMLOG,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.SystemLog)
      })
    ,

    'DeviceSiiRestore' : _reflection.GeneratedProtocolMessageType('DeviceSiiRestore', (_message.Message,), {

      'Success' : _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_SUCCESS,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Success)
        })
      ,

      'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
        'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE_ERROR,
        '__module__' : 'motion_master_pb2'
        # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceSiiRestore.Error)
        })
      ,
      'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS_DEVICESIIRESTORE,
      '__module__' : 'motion_master_pb2'
      # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status.DeviceSiiRestore)
      })
    ,
    'DESCRIPTOR' : _MOTIONMASTERMESSAGE_STATUS,
    '__module__' : 'motion_master_pb2'
    # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage.Status)
    })
  ,
  'DESCRIPTOR' : _MOTIONMASTERMESSAGE,
  '__module__' : 'motion_master_pb2'
  # @@protoc_insertion_point(class_scope:motionmaster.MotionMasterMessage)
  })
_sym_db.RegisterMessage(MotionMasterMessage)
_sym_db.RegisterMessage(MotionMasterMessage.Request)
_sym_db.RegisterMessage(MotionMasterMessage.Request.PingSystem)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetSystemVersion)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceInfo)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceParameterInfo)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceParameterValues.Parameter)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetMultiDeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetDeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetDeviceParameterValues.ParameterValue)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetMultiDeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceFileList)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceFile)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetDeviceFile)
_sym_db.RegisterMessage(MotionMasterMessage.Request.DeleteDeviceFile)
_sym_db.RegisterMessage(MotionMasterMessage.Request.ResetDeviceFault)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StopDevice)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartDeviceFirmwareInstallation)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceLog)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartCoggingTorqueRecording)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetCoggingTorqueData)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartOffsetDetection)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartPlantIdentification)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartSystemIdentification)
_sym_db.RegisterMessage(MotionMasterMessage.Request.ComputeAutoTuningGains)
_sym_db.RegisterMessage(MotionMasterMessage.Request.ComputeAutoTuningGains.PositionParameters)
_sym_db.RegisterMessage(MotionMasterMessage.Request.ComputeAutoTuningGains.VelocityParameters)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetMotionControllerParameters)
_sym_db.RegisterMessage(MotionMasterMessage.Request.EnableMotionController)
_sym_db.RegisterMessage(MotionMasterMessage.Request.DisableMotionController)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionStepResponse)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionAdvancedStepResponse)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionRamp)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionTrapezoidal)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionBidirectional)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.PositionSineWave)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityStepResponse)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityAdvancedStepResponse)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityRamp)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityTrapezoidal)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocityBidirectional)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.VelocitySineWave)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueStepResponse)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueAdvancedStepResponse)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueRamp)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueTrapezoidal)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueBidirectional)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSignalGeneratorParameters.TorqueSineWave)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartSignalGenerator)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StopSignalGenerator)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartMonitoringDeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StopMonitoringDeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetEthercatNetworkState)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetEthercatNetworkState)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartNarrowAngleCalibration)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetSystemClientTimeout)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetCirculoEncoderMagnetDistance)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartCirculoEncoderNarrowAngleCalibrationProcedure)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetDeviceCiA402State)
_sym_db.RegisterMessage(MotionMasterMessage.Request.SetDeviceCiA402State)
_sym_db.RegisterMessage(MotionMasterMessage.Request.GetSystemLog)
_sym_db.RegisterMessage(MotionMasterMessage.Request.StartDeviceSiiRestore)
_sym_db.RegisterMessage(MotionMasterMessage.Status)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemPong)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemVersion)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemEvent)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemEvent.Info)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemEvent.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemEvent.Warning)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemEvent.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceInfo)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceInfo.Device)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceParameterInfo)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceParameterInfo.Parameter)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceParameterValues.ParameterValue)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceParameterValues.ParameterValue.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceParameterValues.Progress)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MultiDeviceParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFileList)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFileList.FileList)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFileList.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFile)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFile.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFile.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceEvent)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceEvent.Info)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceEvent.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceEvent.Warning)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceEvent.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFirmwareInstallation)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFirmwareInstallation.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFirmwareInstallation.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFirmwareInstallation.Progress)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceLog)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceLog.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFaultReset)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFaultReset.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFaultReset.Warning)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceFaultReset.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CoggingTorqueRecording)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CoggingTorqueRecording.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CoggingTorqueRecording.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CoggingTorqueData)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CoggingTorqueData.Table)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CoggingTorqueData.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.OffsetDetection)
_sym_db.RegisterMessage(MotionMasterMessage.Status.OffsetDetection.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.OffsetDetection.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.PlantIdentification)
_sym_db.RegisterMessage(MotionMasterMessage.Status.PlantIdentification.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.PlantIdentification.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemIdentification)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemIdentification.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemIdentification.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.AutoTuning)
_sym_db.RegisterMessage(MotionMasterMessage.Status.AutoTuning.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.AutoTuning.Warning)
_sym_db.RegisterMessage(MotionMasterMessage.Status.AutoTuning.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MotionController)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MotionController.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MotionController.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SignalGenerator)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SignalGenerator.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SignalGenerator.Warning)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SignalGenerator.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MonitoringParameterValues)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MonitoringParameterValues.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MonitoringParameterValues.Warning)
_sym_db.RegisterMessage(MotionMasterMessage.Status.MonitoringParameterValues.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceStop)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceStop.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceStop.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.EthercatNetworkState)
_sym_db.RegisterMessage(MotionMasterMessage.Status.EthercatNetworkState.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.EthercatNetworkState.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.NarrowAngleCalibration)
_sym_db.RegisterMessage(MotionMasterMessage.Status.NarrowAngleCalibration.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.NarrowAngleCalibration.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CirculoEncoderMagnetDistance)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.CirculoEncoderNarrowAngleCalibrationProcedure.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceCiA402State)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceCiA402State.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceCiA402State.Error)
_sym_db.RegisterMessage(MotionMasterMessage.Status.SystemLog)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceSiiRestore)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceSiiRestore.Success)
_sym_db.RegisterMessage(MotionMasterMessage.Status.DeviceSiiRestore.Error)


DESCRIPTOR._options = None
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_plant_identification']._options = None
_MOTIONMASTERMESSAGE_REQUEST.fields_by_name['start_narrow_angle_calibration']._options = None
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['plant_identification']._options = None
_MOTIONMASTERMESSAGE_STATUS.fields_by_name['narrow_angle_calibration']._options = None
# @@protoc_insertion_point(module_scope)
